/***************************************************************************
 *                                                                         *
 *	 FILE: FONTS.C                                                         *
 *   LCD Display Controller font set. Supports three fonts that are        *
 *   defined in bit map tables in this source file. The font tables in     *
 *   this file were derived from a conversion program called FontGen       *
 *   by Bahri Okuroglu - bahrio@yahoo.com.								   *
 *                                                                         *
 *   Copyright (C) 2003 by Carousel Design Solutions                       *
 *                                                                         *
 *									Written by:                            *
 *									Michael J. Karas                       *
 *									Carousel Design Solutions              *
 *									4217 Grimes Ave South                  *
 *									Edina MN 55416                         *
 *									(952) 929-7537                         *
 *                                                                         *
 ***************************************************************************/

#include <stdarg.h>
#include "fonts.h"


/* definition tables for three fonts as follows:                         */
/* all fonts include 96 glyphs from 0x20 to 0x7F that are in ASCII order */
/*	*/
/*  Font #0: normal_font - a light variable width font that is 13 pixels high */
/*  Font #1: bold_font - a heavy variable width font that is 13 pixels high */
/*  Font #2: bigbold_font - a large fixed width font that is 32 pixels high */
/*  */

struct FONT_DEF code fonts[] = {
                   {2, 13, normal_glyph_table, 0, normal_width_table},	/* normal */
                   {2, 13, bold_glyph_table, 0, bold_width_table},		/* bold */
				   {3, 32, bigbold_glyph_table, 20, NULL},				/* bigbold */
				   };

unsigned char code normal_width_table[] = {
		 3, /* ' ' */
		 3, /* '!' */
		 5, /* '"' */
		 7, /* '#' */
		 6, /* '$' */
		 8, /* '%' */
		 6, /* '&' */
		 2, /* ''' */
		 3, /* '(' */
		 3, /* ')' */
		 4, /* '*' */
		 6, /* '+' */
		 3, /* ',' */
		 3, /* '-' */
		 3, /* '.' */
		 5, /* '/' */
		 6, /* '0' */
		 6, /* '1' */
		 6, /* '2' */
		 6, /* '3' */
		 6, /* '4' */
		 6, /* '5' */
		 6, /* '6' */
		 6, /* '7' */
		 6, /* '8' */
		 6, /* '9' */
		 3, /* ':' */
		 3, /* ';' */
		 6, /* '<' */
		 6, /* '=' */
		 6, /* '>' */
		 6, /* '?' */
		11, /* '@' */
		 7, /* 'A' */
		 7, /* 'B' */
		 7, /* 'C' */
		 8, /* 'D' */
		 7, /* 'E' */
		 6, /* 'F' */
		 8, /* 'G' */
		 8, /* 'H' */
		 3, /* 'I' */
		 5, /* 'J' */
		 7, /* 'K' */
		 6, /* 'L' */
		 9, /* 'M' */
		 8, /* 'N' */
		 8, /* 'O' */
		 7, /* 'P' */
		 8, /* 'Q' */
		 8, /* 'R' */
		 7, /* 'S' */
		 7, /* 'T' */
		 8, /* 'U' */
		 7, /* 'V' */
		11, /* 'W' */
		 7, /* 'X' */
		 7, /* 'Y' */
		 7, /* 'Z' */
		 3, /* '[' */
		 5, /* '\' */
		 3, /* ']' */
		 6, /* '^' */
		 6, /* '_' */
		 3, /* '`' */
		 6, /* 'a' */
		 6, /* 'b' */
		 6, /* 'c' */
		 6, /* 'd' */
		 6, /* 'e' */
		 3, /* 'f' */
		 6, /* 'g' */
		 6, /* 'h' */
		 2, /* 'i' */
		 2, /* 'j' */
		 6, /* 'k' */
		 2, /* 'l' */
		 8, /* 'm' */
		 6, /* 'n' */
		 6, /* 'o' */
		 6, /* 'p' */
		 6, /* 'q' */
		 3, /* 'r' */
		 5, /* 's' */
		 3, /* 't' */
		 6, /* 'u' */
		 6, /* 'v' */
		 8, /* 'w' */
		 5, /* 'x' */
		 5, /* 'y' */
		 5, /* 'z' */
		 4, /* '{' */
		 2, /* '|' */
		 4, /* '}' */
		 7, /* '~' */
        };

unsigned char code normal_glyph_table[] = {
		/* ' ' charwidth: 3 */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		
		/* '!' charwidth: 3 */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		
		/* '"' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x48, 0x00, 	/*  [ *  *]  */
		0x48, 0x00, 	/*  [ *  *]  */
		0x48, 0x00, 	/*  [ *  *]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		
		/* '#' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x24, 0x00, 	/*  [  *  * ]  */
		0x24, 0x00, 	/*  [  *  * ]  */
		0x7E, 0x00, 	/*  [ ******]  */
		0x24, 0x00, 	/*  [  *  * ]  */
		0x24, 0x00, 	/*  [  *  * ]  */
		0x24, 0x00, 	/*  [  *  * ]  */
		0x7E, 0x00, 	/*  [ ******]  */
		0x24, 0x00, 	/*  [  *  * ]  */
		0x24, 0x00, 	/*  [  *  * ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		
		/* '$' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x54, 0x00, 	/*  [ * * *]  */
		0x50, 0x00, 	/*  [ * *  ]  */
		0x30, 0x00, 	/*  [  **  ]  */
		0x18, 0x00, 	/*  [   ** ]  */
		0x14, 0x00, 	/*  [   * *]  */
		0x54, 0x00, 	/*  [ * * *]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* '%' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x30, 0x00, 	/*  [  **    ]  */
		0x49, 0x00, 	/*  [ *  *  *]  */
		0x32, 0x00, 	/*  [  **  * ]  */
		0x04, 0x00, 	/*  [     *  ]  */
		0x08, 0x00, 	/*  [    *   ]  */
		0x10, 0x00, 	/*  [   *    ]  */
		0x26, 0x00, 	/*  [  *  ** ]  */
		0x49, 0x00, 	/*  [ *  *  *]  */
		0x06, 0x00, 	/*  [     ** ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* '&' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x20, 0x00, 	/*  [  *   ]  */
		0x50, 0x00, 	/*  [ * *  ]  */
		0x50, 0x00, 	/*  [ * *  ]  */
		0x20, 0x00, 	/*  [  *   ]  */
		0x20, 0x00, 	/*  [  *   ]  */
		0x54, 0x00, 	/*  [ * * *]  */
		0x48, 0x00, 	/*  [ *  * ]  */
		0x48, 0x00, 	/*  [ *  * ]  */
		0x34, 0x00, 	/*  [  ** *]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* ''' charwidth: 2 */
		0x00, 0x00, 	/*  [  ]  */
		0x00, 0x00, 	/*  [  ]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x00, 0x00, 	/*  [  ]  */
		0x00, 0x00, 	/*  [  ]  */
		0x00, 0x00, 	/*  [  ]  */
		0x00, 0x00, 	/*  [  ]  */
		0x00, 0x00, 	/*  [  ]  */
		0x00, 0x00, 	/*  [  ]  */
		0x00, 0x00, 	/*  [  ]  */
		0x00, 0x00, 	/*  [  ]  */
		
		/* '(' charwidth: 3 */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x20, 0x00, 	/*  [  *]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x20, 0x00, 	/*  [  *]  */
		
		/* ')' charwidth: 3 */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x20, 0x00, 	/*  [  *]  */
		0x20, 0x00, 	/*  [  *]  */
		0x20, 0x00, 	/*  [  *]  */
		0x20, 0x00, 	/*  [  *]  */
		0x20, 0x00, 	/*  [  *]  */
		0x20, 0x00, 	/*  [  *]  */
		0x20, 0x00, 	/*  [  *]  */
		0x20, 0x00, 	/*  [  *]  */
		0x20, 0x00, 	/*  [  *]  */
		0x40, 0x00, 	/*  [ * ]  */
		
		/* '*' charwidth: 4 */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x50, 0x00, 	/*  [ * *]  */
		0x20, 0x00, 	/*  [  * ]  */
		0x50, 0x00, 	/*  [ * *]  */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		
		/* '+' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x7C, 0x00, 	/*  [ *****]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* ',' charwidth: 3 */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x20, 0x00, 	/*  [  *]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x00, 0x00, 	/*  [   ]  */
		
		/* '-' charwidth: 3 */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x60, 0x00, 	/*  [ **]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		
		/* '.' charwidth: 3 */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		
		/* '/' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x08, 0x00, 	/*  [    *]  */
		0x08, 0x00, 	/*  [    *]  */
		0x08, 0x00, 	/*  [    *]  */
		0x10, 0x00, 	/*  [   * ]  */
		0x10, 0x00, 	/*  [   * ]  */
		0x20, 0x00, 	/*  [  *  ]  */
		0x20, 0x00, 	/*  [  *  ]  */
		0x40, 0x00, 	/*  [ *   ]  */
		0x40, 0x00, 	/*  [ *   ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		
		/* '0' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* '1' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x70, 0x00, 	/*  [ ***  ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* '2' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x04, 0x00, 	/*  [     *]  */
		0x04, 0x00, 	/*  [     *]  */
		0x08, 0x00, 	/*  [    * ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x20, 0x00, 	/*  [  *   ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x7C, 0x00, 	/*  [ *****]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* '3' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x04, 0x00, 	/*  [     *]  */
		0x04, 0x00, 	/*  [     *]  */
		0x18, 0x00, 	/*  [   ** ]  */
		0x04, 0x00, 	/*  [     *]  */
		0x04, 0x00, 	/*  [     *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* '4' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x08, 0x00, 	/*  [    * ]  */
		0x18, 0x00, 	/*  [   ** ]  */
		0x18, 0x00, 	/*  [   ** ]  */
		0x28, 0x00, 	/*  [  * * ]  */
		0x28, 0x00, 	/*  [  * * ]  */
		0x48, 0x00, 	/*  [ *  * ]  */
		0x7C, 0x00, 	/*  [ *****]  */
		0x08, 0x00, 	/*  [    * ]  */
		0x08, 0x00, 	/*  [    * ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* '5' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x7C, 0x00, 	/*  [ *****]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x78, 0x00, 	/*  [ **** ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x04, 0x00, 	/*  [     *]  */
		0x04, 0x00, 	/*  [     *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* '6' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x78, 0x00, 	/*  [ **** ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* '7' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x7C, 0x00, 	/*  [ *****]  */
		0x04, 0x00, 	/*  [     *]  */
		0x08, 0x00, 	/*  [    * ]  */
		0x08, 0x00, 	/*  [    * ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x20, 0x00, 	/*  [  *   ]  */
		0x20, 0x00, 	/*  [  *   ]  */
		0x20, 0x00, 	/*  [  *   ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* '8' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* '9' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x3C, 0x00, 	/*  [  ****]  */
		0x04, 0x00, 	/*  [     *]  */
		0x04, 0x00, 	/*  [     *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* ':' charwidth: 3 */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		
		/* ';' charwidth: 3 */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x20, 0x00, 	/*  [  *]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x20, 0x00, 	/*  [  *]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x00, 0x00, 	/*  [   ]  */
		
		/* '<' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x08, 0x00, 	/*  [    * ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x20, 0x00, 	/*  [  *   ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x20, 0x00, 	/*  [  *   ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x08, 0x00, 	/*  [    * ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* '=' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x7C, 0x00, 	/*  [ *****]  */
		0x00, 0x00, 	/*  [      ]  */
		0x7C, 0x00, 	/*  [ *****]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* '>' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x20, 0x00, 	/*  [  *   ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x08, 0x00, 	/*  [    * ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x20, 0x00, 	/*  [  *   ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* '?' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x04, 0x00, 	/*  [     *]  */
		0x04, 0x00, 	/*  [     *]  */
		0x08, 0x00, 	/*  [    * ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* '@' charwidth: 11 */
		0x00, 0x00, 	/*  [           ]  */
		0x00, 0x00, 	/*  [           ]  */
		0x0F, 0x00, 	/*  [    ****   ]  */
		0x30, 0xC0, 	/*  [  **    ** ]  */
		0x20, 0x40, 	/*  [  *      * ]  */
		0x47, 0x20, 	/*  [ *   ***  *]  */
		0x49, 0x20, 	/*  [ *  *  *  *]  */
		0x49, 0x20, 	/*  [ *  *  *  *]  */
		0x46, 0xE0, 	/*  [ *   ** ***]  */
		0x20, 0x00, 	/*  [  *        ]  */
		0x30, 0x00, 	/*  [  **       ]  */
		0x0F, 0x80, 	/*  [    *****  ]  */
		0x00, 0x00, 	/*  [           ]  */
		
		/* 'A' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x10, 0x00, 	/*  [   *   ]  */
		0x10, 0x00, 	/*  [   *   ]  */
		0x28, 0x00, 	/*  [  * *  ]  */
		0x28, 0x00, 	/*  [  * *  ]  */
		0x44, 0x00, 	/*  [ *   * ]  */
		0x44, 0x00, 	/*  [ *   * ]  */
		0x7C, 0x00, 	/*  [ ***** ]  */
		0x82, 0x00, 	/*  [*     *]  */
		0x82, 0x00, 	/*  [*     *]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		
		/* 'B' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x78, 0x00, 	/*  [ ****  ]  */
		0x44, 0x00, 	/*  [ *   * ]  */
		0x44, 0x00, 	/*  [ *   * ]  */
		0x44, 0x00, 	/*  [ *   * ]  */
		0x78, 0x00, 	/*  [ ****  ]  */
		0x44, 0x00, 	/*  [ *   * ]  */
		0x44, 0x00, 	/*  [ *   * ]  */
		0x44, 0x00, 	/*  [ *   * ]  */
		0x78, 0x00, 	/*  [ ****  ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		
		/* 'C' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x3C, 0x00, 	/*  [  **** ]  */
		0x42, 0x00, 	/*  [ *    *]  */
		0x40, 0x00, 	/*  [ *     ]  */
		0x40, 0x00, 	/*  [ *     ]  */
		0x40, 0x00, 	/*  [ *     ]  */
		0x40, 0x00, 	/*  [ *     ]  */
		0x40, 0x00, 	/*  [ *     ]  */
		0x42, 0x00, 	/*  [ *    *]  */
		0x3C, 0x00, 	/*  [  **** ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		
		/* 'D' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x78, 0x00, 	/*  [ ****   ]  */
		0x44, 0x00, 	/*  [ *   *  ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x44, 0x00, 	/*  [ *   *  ]  */
		0x78, 0x00, 	/*  [ ****   ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'E' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x7C, 0x00, 	/*  [ ***** ]  */
		0x40, 0x00, 	/*  [ *     ]  */
		0x40, 0x00, 	/*  [ *     ]  */
		0x40, 0x00, 	/*  [ *     ]  */
		0x78, 0x00, 	/*  [ ****  ]  */
		0x40, 0x00, 	/*  [ *     ]  */
		0x40, 0x00, 	/*  [ *     ]  */
		0x40, 0x00, 	/*  [ *     ]  */
		0x7C, 0x00, 	/*  [ ***** ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		
		/* 'F' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x7C, 0x00, 	/*  [ *****]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x78, 0x00, 	/*  [ **** ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* 'G' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x40, 0x00, 	/*  [ *      ]  */
		0x40, 0x00, 	/*  [ *      ]  */
		0x4E, 0x00, 	/*  [ *  *** ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x46, 0x00, 	/*  [ *   ** ]  */
		0x3A, 0x00, 	/*  [  *** * ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'H' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x7E, 0x00, 	/*  [ ****** ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'I' charwidth: 3 */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		
		/* 'J' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x10, 0x00, 	/*  [   * ]  */
		0x10, 0x00, 	/*  [   * ]  */
		0x10, 0x00, 	/*  [   * ]  */
		0x10, 0x00, 	/*  [   * ]  */
		0x10, 0x00, 	/*  [   * ]  */
		0x10, 0x00, 	/*  [   * ]  */
		0x90, 0x00, 	/*  [*  * ]  */
		0x90, 0x00, 	/*  [*  * ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		
		/* 'K' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x44, 0x00, 	/*  [ *   * ]  */
		0x48, 0x00, 	/*  [ *  *  ]  */
		0x50, 0x00, 	/*  [ * *   ]  */
		0x60, 0x00, 	/*  [ **    ]  */
		0x60, 0x00, 	/*  [ **    ]  */
		0x50, 0x00, 	/*  [ * *   ]  */
		0x48, 0x00, 	/*  [ *  *  ]  */
		0x44, 0x00, 	/*  [ *   * ]  */
		0x42, 0x00, 	/*  [ *    *]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		
		/* 'L' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x7C, 0x00, 	/*  [ *****]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* 'M' charwidth: 9 */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x41, 0x00, 	/*  [ *     * ]  */
		0x41, 0x00, 	/*  [ *     * ]  */
		0x63, 0x00, 	/*  [ **   ** ]  */
		0x63, 0x00, 	/*  [ **   ** ]  */
		0x55, 0x00, 	/*  [ * * * * ]  */
		0x55, 0x00, 	/*  [ * * * * ]  */
		0x49, 0x00, 	/*  [ *  *  * ]  */
		0x49, 0x00, 	/*  [ *  *  * ]  */
		0x41, 0x00, 	/*  [ *     * ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		
		/* 'N' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x62, 0x00, 	/*  [ **   * ]  */
		0x62, 0x00, 	/*  [ **   * ]  */
		0x52, 0x00, 	/*  [ * *  * ]  */
		0x52, 0x00, 	/*  [ * *  * ]  */
		0x4A, 0x00, 	/*  [ *  * * ]  */
		0x46, 0x00, 	/*  [ *   ** ]  */
		0x46, 0x00, 	/*  [ *   ** ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'O' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'P' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x7C, 0x00, 	/*  [ ***** ]  */
		0x42, 0x00, 	/*  [ *    *]  */
		0x42, 0x00, 	/*  [ *    *]  */
		0x42, 0x00, 	/*  [ *    *]  */
		0x7C, 0x00, 	/*  [ ***** ]  */
		0x40, 0x00, 	/*  [ *     ]  */
		0x40, 0x00, 	/*  [ *     ]  */
		0x40, 0x00, 	/*  [ *     ]  */
		0x40, 0x00, 	/*  [ *     ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		
		/* 'Q' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x4A, 0x00, 	/*  [ *  * * ]  */
		0x46, 0x00, 	/*  [ *   ** ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x02, 0x00, 	/*  [      * ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'R' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x7C, 0x00, 	/*  [ *****  ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x7C, 0x00, 	/*  [ *****  ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'S' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x38, 0x00, 	/*  [  ***  ]  */
		0x44, 0x00, 	/*  [ *   * ]  */
		0x40, 0x00, 	/*  [ *     ]  */
		0x40, 0x00, 	/*  [ *     ]  */
		0x38, 0x00, 	/*  [  ***  ]  */
		0x04, 0x00, 	/*  [     * ]  */
		0x04, 0x00, 	/*  [     * ]  */
		0x44, 0x00, 	/*  [ *   * ]  */
		0x38, 0x00, 	/*  [  ***  ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		
		/* 'T' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x7C, 0x00, 	/*  [ ***** ]  */
		0x10, 0x00, 	/*  [   *   ]  */
		0x10, 0x00, 	/*  [   *   ]  */
		0x10, 0x00, 	/*  [   *   ]  */
		0x10, 0x00, 	/*  [   *   ]  */
		0x10, 0x00, 	/*  [   *   ]  */
		0x10, 0x00, 	/*  [   *   ]  */
		0x10, 0x00, 	/*  [   *   ]  */
		0x10, 0x00, 	/*  [   *   ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		
		/* 'U' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x42, 0x00, 	/*  [ *    * ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'V' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x82, 0x00, 	/*  [*     *]  */
		0x82, 0x00, 	/*  [*     *]  */
		0x44, 0x00, 	/*  [ *   * ]  */
		0x44, 0x00, 	/*  [ *   * ]  */
		0x44, 0x00, 	/*  [ *   * ]  */
		0x28, 0x00, 	/*  [  * *  ]  */
		0x28, 0x00, 	/*  [  * *  ]  */
		0x10, 0x00, 	/*  [   *   ]  */
		0x10, 0x00, 	/*  [   *   ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		
		/* 'W' charwidth: 11 */
		0x00, 0x00, 	/*  [           ]  */
		0x00, 0x00, 	/*  [           ]  */
		0x80, 0x20, 	/*  [*         *]  */
		0x80, 0x20, 	/*  [*         *]  */
		0x44, 0x40, 	/*  [ *   *   * ]  */
		0x44, 0x40, 	/*  [ *   *   * ]  */
		0x44, 0x40, 	/*  [ *   *   * ]  */
		0x2A, 0x80, 	/*  [  * * * *  ]  */
		0x2A, 0x80, 	/*  [  * * * *  ]  */
		0x11, 0x00, 	/*  [   *   *   ]  */
		0x11, 0x00, 	/*  [   *   *   ]  */
		0x00, 0x00, 	/*  [           ]  */
		0x00, 0x00, 	/*  [           ]  */
		
		/* 'X' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x82, 0x00, 	/*  [*     *]  */
		0x82, 0x00, 	/*  [*     *]  */
		0x44, 0x00, 	/*  [ *   * ]  */
		0x28, 0x00, 	/*  [  * *  ]  */
		0x10, 0x00, 	/*  [   *   ]  */
		0x28, 0x00, 	/*  [  * *  ]  */
		0x44, 0x00, 	/*  [ *   * ]  */
		0x82, 0x00, 	/*  [*     *]  */
		0x82, 0x00, 	/*  [*     *]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		
		/* 'Y' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x82, 0x00, 	/*  [*     *]  */
		0x82, 0x00, 	/*  [*     *]  */
		0x44, 0x00, 	/*  [ *   * ]  */
		0x28, 0x00, 	/*  [  * *  ]  */
		0x10, 0x00, 	/*  [   *   ]  */
		0x10, 0x00, 	/*  [   *   ]  */
		0x10, 0x00, 	/*  [   *   ]  */
		0x10, 0x00, 	/*  [   *   ]  */
		0x10, 0x00, 	/*  [   *   ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		
		/* 'Z' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0xFE, 0x00, 	/*  [*******]  */
		0x02, 0x00, 	/*  [      *]  */
		0x04, 0x00, 	/*  [     * ]  */
		0x08, 0x00, 	/*  [    *  ]  */
		0x10, 0x00, 	/*  [   *   ]  */
		0x20, 0x00, 	/*  [  *    ]  */
		0x40, 0x00, 	/*  [ *     ]  */
		0x80, 0x00, 	/*  [*      ]  */
		0xFE, 0x00, 	/*  [*******]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		
		/* '[' charwidth: 3 */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x60, 0x00, 	/*  [ **]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x60, 0x00, 	/*  [ **]  */
		
		/* '\' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x40, 0x00, 	/*  [ *   ]  */
		0x40, 0x00, 	/*  [ *   ]  */
		0x40, 0x00, 	/*  [ *   ]  */
		0x20, 0x00, 	/*  [  *  ]  */
		0x20, 0x00, 	/*  [  *  ]  */
		0x10, 0x00, 	/*  [   * ]  */
		0x10, 0x00, 	/*  [   * ]  */
		0x08, 0x00, 	/*  [    *]  */
		0x08, 0x00, 	/*  [    *]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		
		/* ']' charwidth: 3 */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x60, 0x00, 	/*  [ **]  */
		0x20, 0x00, 	/*  [  *]  */
		0x20, 0x00, 	/*  [  *]  */
		0x20, 0x00, 	/*  [  *]  */
		0x20, 0x00, 	/*  [  *]  */
		0x20, 0x00, 	/*  [  *]  */
		0x20, 0x00, 	/*  [  *]  */
		0x20, 0x00, 	/*  [  *]  */
		0x20, 0x00, 	/*  [  *]  */
		0x20, 0x00, 	/*  [  *]  */
		0x60, 0x00, 	/*  [ **]  */
		
		/* '^' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x28, 0x00, 	/*  [  * * ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* '_' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0xFC, 0x00, 	/*  [******]  */
		
		/* '`' charwidth: 3 */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x20, 0x00, 	/*  [  *]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		
		/* 'a' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x04, 0x00, 	/*  [     *]  */
		0x3C, 0x00, 	/*  [  ****]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x3C, 0x00, 	/*  [  ****]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* 'b' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x78, 0x00, 	/*  [ **** ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x78, 0x00, 	/*  [ **** ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* 'c' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* 'd' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x04, 0x00, 	/*  [     *]  */
		0x04, 0x00, 	/*  [     *]  */
		0x04, 0x00, 	/*  [     *]  */
		0x3C, 0x00, 	/*  [  ****]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x3C, 0x00, 	/*  [  ****]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* 'e' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x7C, 0x00, 	/*  [ *****]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* 'f' charwidth: 3 */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x20, 0x00, 	/*  [  *]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x60, 0x00, 	/*  [ **]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		
		/* 'g' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x3C, 0x00, 	/*  [  ****]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x3C, 0x00, 	/*  [  ****]  */
		0x04, 0x00, 	/*  [     *]  */
		0x78, 0x00, 	/*  [ **** ]  */
		
		/* 'h' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x58, 0x00, 	/*  [ * ** ]  */
		0x64, 0x00, 	/*  [ **  *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* 'i' charwidth: 2 */
		0x00, 0x00, 	/*  [  ]  */
		0x00, 0x00, 	/*  [  ]  */
		0x40, 0x00, 	/*  [ *]  */
		0x00, 0x00, 	/*  [  ]  */
		0x00, 0x00, 	/*  [  ]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x00, 0x00, 	/*  [  ]  */
		0x00, 0x00, 	/*  [  ]  */
		
		/* 'j' charwidth: 2 */
		0x00, 0x00, 	/*  [  ]  */
		0x00, 0x00, 	/*  [  ]  */
		0x40, 0x00, 	/*  [ *]  */
		0x00, 0x00, 	/*  [  ]  */
		0x00, 0x00, 	/*  [  ]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		
		/* 'k' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x48, 0x00, 	/*  [ *  * ]  */
		0x50, 0x00, 	/*  [ * *  ]  */
		0x60, 0x00, 	/*  [ **   ]  */
		0x50, 0x00, 	/*  [ * *  ]  */
		0x48, 0x00, 	/*  [ *  * ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* 'l' charwidth: 2 */
		0x00, 0x00, 	/*  [  ]  */
		0x00, 0x00, 	/*  [  ]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x00, 0x00, 	/*  [  ]  */
		0x00, 0x00, 	/*  [  ]  */
		
		/* 'm' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x76, 0x00, 	/*  [ *** ** ]  */
		0x49, 0x00, 	/*  [ *  *  *]  */
		0x49, 0x00, 	/*  [ *  *  *]  */
		0x49, 0x00, 	/*  [ *  *  *]  */
		0x49, 0x00, 	/*  [ *  *  *]  */
		0x49, 0x00, 	/*  [ *  *  *]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'n' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x58, 0x00, 	/*  [ * ** ]  */
		0x64, 0x00, 	/*  [ **  *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* 'o' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x38, 0x00, 	/*  [  *** ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* 'p' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x78, 0x00, 	/*  [ **** ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x78, 0x00, 	/*  [ **** ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		0x40, 0x00, 	/*  [ *    ]  */
		
		/* 'q' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x3C, 0x00, 	/*  [  ****]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x3C, 0x00, 	/*  [  ****]  */
		0x04, 0x00, 	/*  [     *]  */
		0x04, 0x00, 	/*  [     *]  */
		
		/* 'r' charwidth: 3 */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x60, 0x00, 	/*  [ **]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		
		/* 's' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x48, 0x00, 	/*  [ *  *]  */
		0x20, 0x00, 	/*  [  *  ]  */
		0x10, 0x00, 	/*  [   * ]  */
		0x48, 0x00, 	/*  [ *  *]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		
		/* 't' charwidth: 3 */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x60, 0x00, 	/*  [ **]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x40, 0x00, 	/*  [ * ]  */
		0x20, 0x00, 	/*  [  *]  */
		0x00, 0x00, 	/*  [   ]  */
		0x00, 0x00, 	/*  [   ]  */
		
		/* 'u' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x4C, 0x00, 	/*  [ *  **]  */
		0x34, 0x00, 	/*  [  ** *]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* 'v' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x44, 0x00, 	/*  [ *   *]  */
		0x28, 0x00, 	/*  [  * * ]  */
		0x28, 0x00, 	/*  [  * * ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x10, 0x00, 	/*  [   *  ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* 'w' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x49, 0x00, 	/*  [ *  *  *]  */
		0x49, 0x00, 	/*  [ *  *  *]  */
		0x55, 0x00, 	/*  [ * * * *]  */
		0x55, 0x00, 	/*  [ * * * *]  */
		0x22, 0x00, 	/*  [  *   * ]  */
		0x22, 0x00, 	/*  [  *   * ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'x' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x48, 0x00, 	/*  [ *  *]  */
		0x48, 0x00, 	/*  [ *  *]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x48, 0x00, 	/*  [ *  *]  */
		0x48, 0x00, 	/*  [ *  *]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		
		/* 'y' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x48, 0x00, 	/*  [ *  *]  */
		0x48, 0x00, 	/*  [ *  *]  */
		0x48, 0x00, 	/*  [ *  *]  */
		0x48, 0x00, 	/*  [ *  *]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x20, 0x00, 	/*  [  *  ]  */
		0x20, 0x00, 	/*  [  *  ]  */
		0xC0, 0x00, 	/*  [**   ]  */
		
		/* 'z' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x78, 0x00, 	/*  [ ****]  */
		0x08, 0x00, 	/*  [    *]  */
		0x10, 0x00, 	/*  [   * ]  */
		0x20, 0x00, 	/*  [  *  ]  */
		0x40, 0x00, 	/*  [ *   ]  */
		0x78, 0x00, 	/*  [ ****]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		
		/* '{' charwidth: 4 */
		0x00, 0x00, 	/*  [    ]  */
		0x10, 0x00, 	/*  [   *]  */
		0x20, 0x00, 	/*  [  * ]  */
		0x20, 0x00, 	/*  [  * ]  */
		0x20, 0x00, 	/*  [  * ]  */
		0x20, 0x00, 	/*  [  * ]  */
		0x40, 0x00, 	/*  [ *  ]  */
		0x20, 0x00, 	/*  [  * ]  */
		0x20, 0x00, 	/*  [  * ]  */
		0x20, 0x00, 	/*  [  * ]  */
		0x20, 0x00, 	/*  [  * ]  */
		0x10, 0x00, 	/*  [   *]  */
		0x00, 0x00, 	/*  [    ]  */
		
		/* '|' charwidth: 2 */
		0x00, 0x00, 	/*  [  ]  */
		0x00, 0x00, 	/*  [  ]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x40, 0x00, 	/*  [ *]  */
		0x00, 0x00, 	/*  [  ]  */
		
		/* '}' charwidth: 4 */
		0x00, 0x00, 	/*  [    ]  */
		0x40, 0x00, 	/*  [ *  ]  */
		0x20, 0x00, 	/*  [  * ]  */
		0x20, 0x00, 	/*  [  * ]  */
		0x20, 0x00, 	/*  [  * ]  */
		0x20, 0x00, 	/*  [  * ]  */
		0x10, 0x00, 	/*  [   *]  */
		0x20, 0x00, 	/*  [  * ]  */
		0x20, 0x00, 	/*  [  * ]  */
		0x20, 0x00, 	/*  [  * ]  */
		0x20, 0x00, 	/*  [  * ]  */
		0x40, 0x00, 	/*  [ *  ]  */
		0x00, 0x00, 	/*  [    ]  */
		
		/* '~' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x32, 0x00, 	/*  [  **  *]  */
		0x4C, 0x00, 	/*  [ *  ** ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
     };

unsigned char code bold_width_table[] = {
		 5, /* ' ' */
		 5, /* '!' */
		 7, /* '"' */
		 9, /* '#' */
		 8, /* '$' */
		10, /* '%' */
		 8, /* '&' */
		 4, /* ''' */
		 5, /* '(' */
		 5, /* ')' */
		 6, /* '*' */
		 8, /* '+' */
		 5, /* ',' */
		 5, /* '-' */
		 5, /* '.' */
		 7, /* '/' */
		 8, /* '0' */
		 8, /* '1' */
		 8, /* '2' */
		 8, /* '3' */
		 8, /* '4' */
		 8, /* '5' */
		 8, /* '6' */
		 8, /* '7' */
		 8, /* '8' */
		 8, /* '9' */
		 5, /* ':' */
		 5, /* ';' */
		 8, /* '<' */
		 8, /* '=' */
		 8, /* '>' */
		 8, /* '?' */
		13, /* '@' */
		 9, /* 'A' */
		 9, /* 'B' */
		 9, /* 'C' */
		10, /* 'D' */
		 9, /* 'E' */
		 8, /* 'F' */
		10, /* 'G' */
		10, /* 'H' */
		 5, /* 'I' */
		 7, /* 'J' */
		 9, /* 'K' */
		 8, /* 'L' */
		11, /* 'M' */
		10, /* 'N' */
		10, /* 'O' */
		 9, /* 'P' */
		10, /* 'Q' */
		10, /* 'R' */
		 9, /* 'S' */
		 9, /* 'T' */
		10, /* 'U' */
		 9, /* 'V' */
		13, /* 'W' */
		 9, /* 'X' */
		 9, /* 'Y' */
		 9, /* 'Z' */
		 5, /* '[' */
		 7, /* '\' */
		 5, /* ']' */
		 8, /* '^' */
		 8, /* '_' */
		 5, /* '`' */
		 8, /* 'a' */
		 8, /* 'b' */
		 8, /* 'c' */
		 8, /* 'd' */
		 8, /* 'e' */
		 5, /* 'f' */
		 8, /* 'g' */
		 8, /* 'h' */
		 4, /* 'i' */
		 4, /* 'j' */
		 8, /* 'k' */
		 4, /* 'l' */
		10, /* 'm' */
		 8, /* 'n' */
		 8, /* 'o' */
		 8, /* 'p' */
		 8, /* 'q' */
		 5, /* 'r' */
		 7, /* 's' */
		 5, /* 't' */
		 8, /* 'u' */
		 8, /* 'v' */
		10, /* 'w' */
		 7, /* 'x' */
		 7, /* 'y' */
		 7, /* 'z' */
		 6, /* '{' */
		 4, /* '|' */
		 6, /* '}' */
		 9, /* '~' */
        };

unsigned char code bold_glyph_table[] = {
		/* ' ' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		
		/* '!' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		
		/* '"' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x6C, 0x00, 	/*  [ ** ** ]  */
		0x6C, 0x00, 	/*  [ ** ** ]  */
		0x6C, 0x00, 	/*  [ ** ** ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		
		/* '#' charwidth: 9 */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x36, 0x00, 	/*  [  ** **  ]  */
		0x36, 0x00, 	/*  [  ** **  ]  */
		0x7F, 0x00, 	/*  [ ******* ]  */
		0x36, 0x00, 	/*  [  ** **  ]  */
		0x36, 0x00, 	/*  [  ** **  ]  */
		0x36, 0x00, 	/*  [  ** **  ]  */
		0x7F, 0x00, 	/*  [ ******* ]  */
		0x36, 0x00, 	/*  [  ** **  ]  */
		0x36, 0x00, 	/*  [  ** **  ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		
		/* '$' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x7E, 0x00, 	/*  [ ****** ]  */
		0x78, 0x00, 	/*  [ ****   ]  */
		0x38, 0x00, 	/*  [  ***   ]  */
		0x1C, 0x00, 	/*  [   ***  ]  */
		0x1E, 0x00, 	/*  [   **** ]  */
		0x7E, 0x00, 	/*  [ ****** ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* '%' charwidth: 10 */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x38, 0x00, 	/*  [  ***     ]  */
		0x6D, 0x80, 	/*  [ ** ** ** ]  */
		0x3B, 0x00, 	/*  [  *** **  ]  */
		0x06, 0x00, 	/*  [     **   ]  */
		0x0C, 0x00, 	/*  [    **    ]  */
		0x18, 0x00, 	/*  [   **     ]  */
		0x37, 0x00, 	/*  [  ** ***  ]  */
		0x6D, 0x80, 	/*  [ ** ** ** ]  */
		0x07, 0x00, 	/*  [     ***  ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		
		/* '&' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x30, 0x00, 	/*  [  **    ]  */
		0x78, 0x00, 	/*  [ ****   ]  */
		0x78, 0x00, 	/*  [ ****   ]  */
		0x30, 0x00, 	/*  [  **    ]  */
		0x30, 0x00, 	/*  [  **    ]  */
		0x7E, 0x00, 	/*  [ ****** ]  */
		0x6C, 0x00, 	/*  [ ** **  ]  */
		0x6C, 0x00, 	/*  [ ** **  ]  */
		0x3E, 0x00, 	/*  [  ***** ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* ''' charwidth: 4 */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		
		/* '(' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		
		/* ')' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		
		/* '*' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x78, 0x00, 	/*  [ **** ]  */
		0x30, 0x00, 	/*  [  **  ]  */
		0x78, 0x00, 	/*  [ **** ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* '+' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x7E, 0x00, 	/*  [ ****** ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* ',' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x00, 0x00, 	/*  [     ]  */
		
		/* '-' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x70, 0x00, 	/*  [ *** ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		
		/* '.' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		
		/* '/' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x0C, 0x00, 	/*  [    ** ]  */
		0x0C, 0x00, 	/*  [    ** ]  */
		0x0C, 0x00, 	/*  [    ** ]  */
		0x18, 0x00, 	/*  [   **  ]  */
		0x18, 0x00, 	/*  [   **  ]  */
		0x30, 0x00, 	/*  [  **   ]  */
		0x30, 0x00, 	/*  [  **   ]  */
		0x60, 0x00, 	/*  [ **    ]  */
		0x60, 0x00, 	/*  [ **    ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		
		/* '0' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* '1' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x78, 0x00, 	/*  [ ****   ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* '2' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x06, 0x00, 	/*  [     ** ]  */
		0x06, 0x00, 	/*  [     ** ]  */
		0x0C, 0x00, 	/*  [    **  ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x30, 0x00, 	/*  [  **    ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x7E, 0x00, 	/*  [ ****** ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* '3' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x06, 0x00, 	/*  [     ** ]  */
		0x06, 0x00, 	/*  [     ** ]  */
		0x1C, 0x00, 	/*  [   ***  ]  */
		0x06, 0x00, 	/*  [     ** ]  */
		0x06, 0x00, 	/*  [     ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* '4' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x0C, 0x00, 	/*  [    **  ]  */
		0x1C, 0x00, 	/*  [   ***  ]  */
		0x1C, 0x00, 	/*  [   ***  ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x6C, 0x00, 	/*  [ ** **  ]  */
		0x7E, 0x00, 	/*  [ ****** ]  */
		0x0C, 0x00, 	/*  [    **  ]  */
		0x0C, 0x00, 	/*  [    **  ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* '5' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x7E, 0x00, 	/*  [ ****** ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x7C, 0x00, 	/*  [ *****  ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x06, 0x00, 	/*  [     ** ]  */
		0x06, 0x00, 	/*  [     ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* '6' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x7C, 0x00, 	/*  [ *****  ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* '7' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x7E, 0x00, 	/*  [ ****** ]  */
		0x06, 0x00, 	/*  [     ** ]  */
		0x0C, 0x00, 	/*  [    **  ]  */
		0x0C, 0x00, 	/*  [    **  ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x30, 0x00, 	/*  [  **    ]  */
		0x30, 0x00, 	/*  [  **    ]  */
		0x30, 0x00, 	/*  [  **    ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* '8' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* '9' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x3E, 0x00, 	/*  [  ***** ]  */
		0x06, 0x00, 	/*  [     ** ]  */
		0x06, 0x00, 	/*  [     ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* ':' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		
		/* ';' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x00, 0x00, 	/*  [     ]  */
		
		/* '<' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x0C, 0x00, 	/*  [    **  ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x30, 0x00, 	/*  [  **    ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x30, 0x00, 	/*  [  **    ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x0C, 0x00, 	/*  [    **  ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* '=' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x7E, 0x00, 	/*  [ ****** ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x7E, 0x00, 	/*  [ ****** ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* '>' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x30, 0x00, 	/*  [  **    ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x0C, 0x00, 	/*  [    **  ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x30, 0x00, 	/*  [  **    ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* '?' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x06, 0x00, 	/*  [     ** ]  */
		0x06, 0x00, 	/*  [     ** ]  */
		0x0C, 0x00, 	/*  [    **  ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* '@' charwidth: 13 */
		0x00, 0x00, 	/*  [             ]  */
		0x00, 0x00, 	/*  [             ]  */
		0x0F, 0x80, 	/*  [    *****    ]  */
		0x38, 0xE0, 	/*  [  ***   ***  ]  */
		0x30, 0x60, 	/*  [  **     **  ]  */
		0x67, 0xB0, 	/*  [ **  **** ** ]  */
		0x6D, 0xB0, 	/*  [ ** ** ** ** ]  */
		0x6D, 0xB0, 	/*  [ ** ** ** ** ]  */
		0x67, 0xF0, 	/*  [ **  ******* ]  */
		0x30, 0x00, 	/*  [  **         ]  */
		0x38, 0x00, 	/*  [  ***        ]  */
		0x0F, 0xC0, 	/*  [    ******   ]  */
		0x00, 0x00, 	/*  [             ]  */
		
		/* 'A' charwidth: 9 */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x18, 0x00, 	/*  [   **    ]  */
		0x18, 0x00, 	/*  [   **    ]  */
		0x3C, 0x00, 	/*  [  ****   ]  */
		0x3C, 0x00, 	/*  [  ****   ]  */
		0x66, 0x00, 	/*  [ **  **  ]  */
		0x66, 0x00, 	/*  [ **  **  ]  */
		0x7E, 0x00, 	/*  [ ******  ]  */
		0xC3, 0x00, 	/*  [**    ** ]  */
		0xC3, 0x00, 	/*  [**    ** ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		
		/* 'B' charwidth: 9 */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x7C, 0x00, 	/*  [ *****   ]  */
		0x66, 0x00, 	/*  [ **  **  ]  */
		0x66, 0x00, 	/*  [ **  **  ]  */
		0x66, 0x00, 	/*  [ **  **  ]  */
		0x7C, 0x00, 	/*  [ *****   ]  */
		0x66, 0x00, 	/*  [ **  **  ]  */
		0x66, 0x00, 	/*  [ **  **  ]  */
		0x66, 0x00, 	/*  [ **  **  ]  */
		0x7C, 0x00, 	/*  [ *****   ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		
		/* 'C' charwidth: 9 */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x3E, 0x00, 	/*  [  *****  ]  */
		0x63, 0x00, 	/*  [ **   ** ]  */
		0x60, 0x00, 	/*  [ **      ]  */
		0x60, 0x00, 	/*  [ **      ]  */
		0x60, 0x00, 	/*  [ **      ]  */
		0x60, 0x00, 	/*  [ **      ]  */
		0x60, 0x00, 	/*  [ **      ]  */
		0x63, 0x00, 	/*  [ **   ** ]  */
		0x3E, 0x00, 	/*  [  *****  ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		
		/* 'D' charwidth: 10 */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x7C, 0x00, 	/*  [ *****    ]  */
		0x66, 0x00, 	/*  [ **  **   ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x66, 0x00, 	/*  [ **  **   ]  */
		0x7C, 0x00, 	/*  [ *****    ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		
		/* 'E' charwidth: 9 */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x7E, 0x00, 	/*  [ ******  ]  */
		0x60, 0x00, 	/*  [ **      ]  */
		0x60, 0x00, 	/*  [ **      ]  */
		0x60, 0x00, 	/*  [ **      ]  */
		0x7C, 0x00, 	/*  [ *****   ]  */
		0x60, 0x00, 	/*  [ **      ]  */
		0x60, 0x00, 	/*  [ **      ]  */
		0x60, 0x00, 	/*  [ **      ]  */
		0x7E, 0x00, 	/*  [ ******  ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		
		/* 'F' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x7E, 0x00, 	/*  [ ****** ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x7C, 0x00, 	/*  [ *****  ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'G' charwidth: 10 */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x3E, 0x00, 	/*  [  *****   ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x60, 0x00, 	/*  [ **       ]  */
		0x60, 0x00, 	/*  [ **       ]  */
		0x6F, 0x00, 	/*  [ ** ****  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x67, 0x00, 	/*  [ **  ***  ]  */
		0x3F, 0x00, 	/*  [  ******  ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		
		/* 'H' charwidth: 10 */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x7F, 0x00, 	/*  [ *******  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		
		/* 'I' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		
		/* 'J' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x18, 0x00, 	/*  [   **  ]  */
		0x18, 0x00, 	/*  [   **  ]  */
		0x18, 0x00, 	/*  [   **  ]  */
		0x18, 0x00, 	/*  [   **  ]  */
		0x18, 0x00, 	/*  [   **  ]  */
		0x18, 0x00, 	/*  [   **  ]  */
		0xD8, 0x00, 	/*  [** **  ]  */
		0xD8, 0x00, 	/*  [** **  ]  */
		0x70, 0x00, 	/*  [ ***   ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		
		/* 'K' charwidth: 9 */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x66, 0x00, 	/*  [ **  **  ]  */
		0x6C, 0x00, 	/*  [ ** **   ]  */
		0x78, 0x00, 	/*  [ ****    ]  */
		0x70, 0x00, 	/*  [ ***     ]  */
		0x70, 0x00, 	/*  [ ***     ]  */
		0x78, 0x00, 	/*  [ ****    ]  */
		0x6C, 0x00, 	/*  [ ** **   ]  */
		0x66, 0x00, 	/*  [ **  **  ]  */
		0x63, 0x00, 	/*  [ **   ** ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		
		/* 'L' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x7E, 0x00, 	/*  [ ****** ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'M' charwidth: 11 */
		0x00, 0x00, 	/*  [           ]  */
		0x00, 0x00, 	/*  [           ]  */
		0x61, 0x80, 	/*  [ **    **  ]  */
		0x61, 0x80, 	/*  [ **    **  ]  */
		0x73, 0x80, 	/*  [ ***  ***  ]  */
		0x73, 0x80, 	/*  [ ***  ***  ]  */
		0x7F, 0x80, 	/*  [ ********  ]  */
		0x7F, 0x80, 	/*  [ ********  ]  */
		0x6D, 0x80, 	/*  [ ** ** **  ]  */
		0x6D, 0x80, 	/*  [ ** ** **  ]  */
		0x61, 0x80, 	/*  [ **    **  ]  */
		0x00, 0x00, 	/*  [           ]  */
		0x00, 0x00, 	/*  [           ]  */
		
		/* 'N' charwidth: 10 */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x73, 0x00, 	/*  [ ***  **  ]  */
		0x73, 0x00, 	/*  [ ***  **  ]  */
		0x7B, 0x00, 	/*  [ **** **  ]  */
		0x7B, 0x00, 	/*  [ **** **  ]  */
		0x6F, 0x00, 	/*  [ ** ****  ]  */
		0x67, 0x00, 	/*  [ **  ***  ]  */
		0x67, 0x00, 	/*  [ **  ***  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		
		/* 'O' charwidth: 10 */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x3E, 0x00, 	/*  [  *****   ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x3E, 0x00, 	/*  [  *****   ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		
		/* 'P' charwidth: 9 */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x7E, 0x00, 	/*  [ ******  ]  */
		0x63, 0x00, 	/*  [ **   ** ]  */
		0x63, 0x00, 	/*  [ **   ** ]  */
		0x63, 0x00, 	/*  [ **   ** ]  */
		0x7E, 0x00, 	/*  [ ******  ]  */
		0x60, 0x00, 	/*  [ **      ]  */
		0x60, 0x00, 	/*  [ **      ]  */
		0x60, 0x00, 	/*  [ **      ]  */
		0x60, 0x00, 	/*  [ **      ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		
		/* 'Q' charwidth: 10 */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x3E, 0x00, 	/*  [  *****   ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x6F, 0x00, 	/*  [ ** ****  ]  */
		0x67, 0x00, 	/*  [ **  ***  ]  */
		0x3E, 0x00, 	/*  [  *****   ]  */
		0x03, 0x00, 	/*  [      **  ]  */
		0x00, 0x00, 	/*  [          ]  */
		
		/* 'R' charwidth: 10 */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x7E, 0x00, 	/*  [ ******   ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x7E, 0x00, 	/*  [ ******   ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		
		/* 'S' charwidth: 9 */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x3C, 0x00, 	/*  [  ****   ]  */
		0x66, 0x00, 	/*  [ **  **  ]  */
		0x60, 0x00, 	/*  [ **      ]  */
		0x60, 0x00, 	/*  [ **      ]  */
		0x3C, 0x00, 	/*  [  ****   ]  */
		0x06, 0x00, 	/*  [     **  ]  */
		0x06, 0x00, 	/*  [     **  ]  */
		0x66, 0x00, 	/*  [ **  **  ]  */
		0x3C, 0x00, 	/*  [  ****   ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		
		/* 'T' charwidth: 9 */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x7E, 0x00, 	/*  [ ******  ]  */
		0x18, 0x00, 	/*  [   **    ]  */
		0x18, 0x00, 	/*  [   **    ]  */
		0x18, 0x00, 	/*  [   **    ]  */
		0x18, 0x00, 	/*  [   **    ]  */
		0x18, 0x00, 	/*  [   **    ]  */
		0x18, 0x00, 	/*  [   **    ]  */
		0x18, 0x00, 	/*  [   **    ]  */
		0x18, 0x00, 	/*  [   **    ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		
		/* 'U' charwidth: 10 */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x63, 0x00, 	/*  [ **   **  ]  */
		0x3E, 0x00, 	/*  [  *****   ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		
		/* 'V' charwidth: 9 */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0xC3, 0x00, 	/*  [**    ** ]  */
		0xC3, 0x00, 	/*  [**    ** ]  */
		0x66, 0x00, 	/*  [ **  **  ]  */
		0x66, 0x00, 	/*  [ **  **  ]  */
		0x66, 0x00, 	/*  [ **  **  ]  */
		0x3C, 0x00, 	/*  [  ****   ]  */
		0x3C, 0x00, 	/*  [  ****   ]  */
		0x18, 0x00, 	/*  [   **    ]  */
		0x18, 0x00, 	/*  [   **    ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		
		/* 'W' charwidth: 13 */
		0x00, 0x00, 	/*  [             ]  */
		0x00, 0x00, 	/*  [             ]  */
		0xC0, 0x30, 	/*  [**        ** ]  */
		0xC0, 0x30, 	/*  [**        ** ]  */
		0x66, 0x60, 	/*  [ **  **  **  ]  */
		0x66, 0x60, 	/*  [ **  **  **  ]  */
		0x66, 0x60, 	/*  [ **  **  **  ]  */
		0x3F, 0xC0, 	/*  [  ********   ]  */
		0x3F, 0xC0, 	/*  [  ********   ]  */
		0x19, 0x80, 	/*  [   **  **    ]  */
		0x19, 0x80, 	/*  [   **  **    ]  */
		0x00, 0x00, 	/*  [             ]  */
		0x00, 0x00, 	/*  [             ]  */
		
		/* 'X' charwidth: 9 */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0xC3, 0x00, 	/*  [**    ** ]  */
		0xC3, 0x00, 	/*  [**    ** ]  */
		0x66, 0x00, 	/*  [ **  **  ]  */
		0x3C, 0x00, 	/*  [  ****   ]  */
		0x18, 0x00, 	/*  [   **    ]  */
		0x3C, 0x00, 	/*  [  ****   ]  */
		0x66, 0x00, 	/*  [ **  **  ]  */
		0xC3, 0x00, 	/*  [**    ** ]  */
		0xC3, 0x00, 	/*  [**    ** ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		
		/* 'Y' charwidth: 9 */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0xC3, 0x00, 	/*  [**    ** ]  */
		0xC3, 0x00, 	/*  [**    ** ]  */
		0x66, 0x00, 	/*  [ **  **  ]  */
		0x3C, 0x00, 	/*  [  ****   ]  */
		0x18, 0x00, 	/*  [   **    ]  */
		0x18, 0x00, 	/*  [   **    ]  */
		0x18, 0x00, 	/*  [   **    ]  */
		0x18, 0x00, 	/*  [   **    ]  */
		0x18, 0x00, 	/*  [   **    ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		
		/* 'Z' charwidth: 9 */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0xFF, 0x00, 	/*  [******** ]  */
		0x03, 0x00, 	/*  [      ** ]  */
		0x06, 0x00, 	/*  [     **  ]  */
		0x0C, 0x00, 	/*  [    **   ]  */
		0x18, 0x00, 	/*  [   **    ]  */
		0x30, 0x00, 	/*  [  **     ]  */
		0x60, 0x00, 	/*  [ **      ]  */
		0xC0, 0x00, 	/*  [**       ]  */
		0xFF, 0x00, 	/*  [******** ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		
		/* '[' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x70, 0x00, 	/*  [ *** ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x70, 0x00, 	/*  [ *** ]  */
		
		/* '\' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x60, 0x00, 	/*  [ **    ]  */
		0x60, 0x00, 	/*  [ **    ]  */
		0x60, 0x00, 	/*  [ **    ]  */
		0x30, 0x00, 	/*  [  **   ]  */
		0x30, 0x00, 	/*  [  **   ]  */
		0x18, 0x00, 	/*  [   **  ]  */
		0x18, 0x00, 	/*  [   **  ]  */
		0x0C, 0x00, 	/*  [    ** ]  */
		0x0C, 0x00, 	/*  [    ** ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		
		/* ']' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x70, 0x00, 	/*  [ *** ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x70, 0x00, 	/*  [ *** ]  */
		
		/* '^' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* '_' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0xFE, 0x00, 	/*  [******* ]  */
		
		/* '`' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		
		/* 'a' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x06, 0x00, 	/*  [     ** ]  */
		0x3E, 0x00, 	/*  [  ***** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x3E, 0x00, 	/*  [  ***** ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'b' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x7C, 0x00, 	/*  [ *****  ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x7C, 0x00, 	/*  [ *****  ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'c' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'd' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x06, 0x00, 	/*  [     ** ]  */
		0x06, 0x00, 	/*  [     ** ]  */
		0x06, 0x00, 	/*  [     ** ]  */
		0x3E, 0x00, 	/*  [  ***** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x3E, 0x00, 	/*  [  ***** ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'e' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x7E, 0x00, 	/*  [ ****** ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'f' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x70, 0x00, 	/*  [ *** ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		
		/* 'g' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x3E, 0x00, 	/*  [  ***** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x3E, 0x00, 	/*  [  ***** ]  */
		0x06, 0x00, 	/*  [     ** ]  */
		0x7C, 0x00, 	/*  [ *****  ]  */
		
		/* 'h' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x7C, 0x00, 	/*  [ *****  ]  */
		0x76, 0x00, 	/*  [ *** ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'i' charwidth: 4 */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		
		/* 'j' charwidth: 4 */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		
		/* 'k' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x6C, 0x00, 	/*  [ ** **  ]  */
		0x78, 0x00, 	/*  [ ****   ]  */
		0x70, 0x00, 	/*  [ ***    ]  */
		0x78, 0x00, 	/*  [ ****   ]  */
		0x6C, 0x00, 	/*  [ ** **  ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'l' charwidth: 4 */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		
		/* 'm' charwidth: 10 */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x7F, 0x00, 	/*  [ *******  ]  */
		0x6D, 0x80, 	/*  [ ** ** ** ]  */
		0x6D, 0x80, 	/*  [ ** ** ** ]  */
		0x6D, 0x80, 	/*  [ ** ** ** ]  */
		0x6D, 0x80, 	/*  [ ** ** ** ]  */
		0x6D, 0x80, 	/*  [ ** ** ** ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		
		/* 'n' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x7C, 0x00, 	/*  [ *****  ]  */
		0x76, 0x00, 	/*  [ *** ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'o' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'p' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x7C, 0x00, 	/*  [ *****  ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x7C, 0x00, 	/*  [ *****  ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		0x60, 0x00, 	/*  [ **     ]  */
		
		/* 'q' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x3E, 0x00, 	/*  [  ***** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x3E, 0x00, 	/*  [  ***** ]  */
		0x06, 0x00, 	/*  [     ** ]  */
		0x06, 0x00, 	/*  [     ** ]  */
		
		/* 'r' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x70, 0x00, 	/*  [ *** ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		
		/* 's' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x38, 0x00, 	/*  [  ***  ]  */
		0x6C, 0x00, 	/*  [ ** ** ]  */
		0x30, 0x00, 	/*  [  **   ]  */
		0x18, 0x00, 	/*  [   **  ]  */
		0x6C, 0x00, 	/*  [ ** ** ]  */
		0x38, 0x00, 	/*  [  ***  ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		
		/* 't' charwidth: 5 */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x70, 0x00, 	/*  [ *** ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x60, 0x00, 	/*  [ **  ]  */
		0x30, 0x00, 	/*  [  ** ]  */
		0x00, 0x00, 	/*  [     ]  */
		0x00, 0x00, 	/*  [     ]  */
		
		/* 'u' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x6E, 0x00, 	/*  [ ** *** ]  */
		0x3E, 0x00, 	/*  [  ***** ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'v' charwidth: 8 */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x66, 0x00, 	/*  [ **  ** ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x3C, 0x00, 	/*  [  ****  ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x18, 0x00, 	/*  [   **   ]  */
		0x00, 0x00, 	/*  [        ]  */
		0x00, 0x00, 	/*  [        ]  */
		
		/* 'w' charwidth: 10 */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x6D, 0x80, 	/*  [ ** ** ** ]  */
		0x6D, 0x80, 	/*  [ ** ** ** ]  */
		0x7F, 0x80, 	/*  [ ******** ]  */
		0x7F, 0x80, 	/*  [ ******** ]  */
		0x33, 0x00, 	/*  [  **  **  ]  */
		0x33, 0x00, 	/*  [  **  **  ]  */
		0x00, 0x00, 	/*  [          ]  */
		0x00, 0x00, 	/*  [          ]  */
		
		/* 'x' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x6C, 0x00, 	/*  [ ** ** ]  */
		0x6C, 0x00, 	/*  [ ** ** ]  */
		0x38, 0x00, 	/*  [  ***  ]  */
		0x38, 0x00, 	/*  [  ***  ]  */
		0x6C, 0x00, 	/*  [ ** ** ]  */
		0x6C, 0x00, 	/*  [ ** ** ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		
		/* 'y' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x6C, 0x00, 	/*  [ ** ** ]  */
		0x6C, 0x00, 	/*  [ ** ** ]  */
		0x6C, 0x00, 	/*  [ ** ** ]  */
		0x6C, 0x00, 	/*  [ ** ** ]  */
		0x38, 0x00, 	/*  [  ***  ]  */
		0x30, 0x00, 	/*  [  **   ]  */
		0x30, 0x00, 	/*  [  **   ]  */
		0xE0, 0x00, 	/*  [***    ]  */
		
		/* 'z' charwidth: 7 */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x7C, 0x00, 	/*  [ ***** ]  */
		0x0C, 0x00, 	/*  [    ** ]  */
		0x18, 0x00, 	/*  [   **  ]  */
		0x30, 0x00, 	/*  [  **   ]  */
		0x60, 0x00, 	/*  [ **    ]  */
		0x7C, 0x00, 	/*  [ ***** ]  */
		0x00, 0x00, 	/*  [       ]  */
		0x00, 0x00, 	/*  [       ]  */
		
		/* '{' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x18, 0x00, 	/*  [   ** ]  */
		0x30, 0x00, 	/*  [  **  ]  */
		0x30, 0x00, 	/*  [  **  ]  */
		0x30, 0x00, 	/*  [  **  ]  */
		0x30, 0x00, 	/*  [  **  ]  */
		0x60, 0x00, 	/*  [ **   ]  */
		0x30, 0x00, 	/*  [  **  ]  */
		0x30, 0x00, 	/*  [  **  ]  */
		0x30, 0x00, 	/*  [  **  ]  */
		0x30, 0x00, 	/*  [  **  ]  */
		0x18, 0x00, 	/*  [   ** ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* '|' charwidth: 4 */
		0x00, 0x00, 	/*  [    ]  */
		0x00, 0x00, 	/*  [    ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x60, 0x00, 	/*  [ ** ]  */
		0x00, 0x00, 	/*  [    ]  */
		
		/* '}' charwidth: 6 */
		0x00, 0x00, 	/*  [      ]  */
		0x60, 0x00, 	/*  [ **   ]  */
		0x30, 0x00, 	/*  [  **  ]  */
		0x30, 0x00, 	/*  [  **  ]  */
		0x30, 0x00, 	/*  [  **  ]  */
		0x30, 0x00, 	/*  [  **  ]  */
		0x18, 0x00, 	/*  [   ** ]  */
		0x30, 0x00, 	/*  [  **  ]  */
		0x30, 0x00, 	/*  [  **  ]  */
		0x30, 0x00, 	/*  [  **  ]  */
		0x30, 0x00, 	/*  [  **  ]  */
		0x60, 0x00, 	/*  [ **   ]  */
		0x00, 0x00, 	/*  [      ]  */
		
		/* '~' charwidth: 9 */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x3B, 0x00, 	/*  [  *** ** ]  */
		0x6E, 0x00, 	/*  [ ** ***  ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
		0x00, 0x00, 	/*  [         ]  */
      };

unsigned char code bigbold_glyph_table[] = {
		/* ' ' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '!' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '"' charwidth: 20 */
		0x0F, 0x8F, 0x80, 	/*  [    *****   *****   ]  */
		0x0F, 0x8F, 0x80, 	/*  [    *****   *****   ]  */
		0x0F, 0x8F, 0x80, 	/*  [    *****   *****   ]  */
		0x0F, 0x8F, 0x80, 	/*  [    *****   *****   ]  */
		0x0F, 0x8F, 0x80, 	/*  [    *****   *****   ]  */
		0x07, 0x07, 0x00, 	/*  [     ***     ***    ]  */
		0x07, 0x07, 0x00, 	/*  [     ***     ***    ]  */
		0x07, 0x07, 0x00, 	/*  [     ***     ***    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '#' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x71, 0xC0, 	/*  [         ***   ***  ]  */
		0x00, 0x71, 0xC0, 	/*  [         ***   ***  ]  */
		0x00, 0xE3, 0x80, 	/*  [        ***   ***   ]  */
		0x00, 0xE3, 0x80, 	/*  [        ***   ***   ]  */
		0x00, 0xE3, 0x80, 	/*  [        ***   ***   ]  */
		0x00, 0xE3, 0x80, 	/*  [        ***   ***   ]  */
		0x01, 0xC7, 0x00, 	/*  [       ***   ***    ]  */
		0x3F, 0xFF, 0xF0, 	/*  [  ******************]  */
		0x3F, 0xFF, 0xF0, 	/*  [  ******************]  */
		0x03, 0x8E, 0x00, 	/*  [      ***   ***     ]  */
		0x03, 0x8E, 0x00, 	/*  [      ***   ***     ]  */
		0x03, 0x8E, 0x00, 	/*  [      ***   ***     ]  */
		0x03, 0x8E, 0x00, 	/*  [      ***   ***     ]  */
		0x03, 0x8E, 0x00, 	/*  [      ***   ***     ]  */
		0x7F, 0xFF, 0xC0, 	/*  [ *****************  ]  */
		0x7F, 0xFF, 0xC0, 	/*  [ *****************  ]  */
		0x07, 0x1C, 0x00, 	/*  [     ***   ***      ]  */
		0x0E, 0x38, 0x00, 	/*  [    ***   ***       ]  */
		0x0E, 0x38, 0x00, 	/*  [    ***   ***       ]  */
		0x0E, 0x38, 0x00, 	/*  [    ***   ***       ]  */
		0x0E, 0x38, 0x00, 	/*  [    ***   ***       ]  */
		0x1C, 0x70, 0x00, 	/*  [   ***   ***        ]  */
		0x1C, 0x70, 0x00, 	/*  [   ***   ***        ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '$' charwidth: 20 */
		0x00, 0x70, 0x00, 	/*  [         ***        ]  */
		0x00, 0x70, 0x00, 	/*  [         ***        ]  */
		0x01, 0xFF, 0x00, 	/*  [       *********    ]  */
		0x03, 0xFF, 0x80, 	/*  [      ***********   ]  */
		0x07, 0xF3, 0x80, 	/*  [     *******  ***   ]  */
		0x0F, 0x70, 0x00, 	/*  [    **** ***        ]  */
		0x0F, 0x70, 0x00, 	/*  [    **** ***        ]  */
		0x0F, 0x70, 0x00, 	/*  [    **** ***        ]  */
		0x0F, 0x70, 0x00, 	/*  [    **** ***        ]  */
		0x0F, 0xF0, 0x00, 	/*  [    ********        ]  */
		0x07, 0xF0, 0x00, 	/*  [     *******        ]  */
		0x03, 0xF0, 0x00, 	/*  [      ******        ]  */
		0x03, 0xF0, 0x00, 	/*  [      ******        ]  */
		0x00, 0xFC, 0x00, 	/*  [        ******      ]  */
		0x00, 0x7F, 0x00, 	/*  [         *******    ]  */
		0x00, 0x7F, 0x80, 	/*  [         ********   ]  */
		0x00, 0x7F, 0x80, 	/*  [         ********   ]  */
		0x00, 0x77, 0xC0, 	/*  [         *** *****  ]  */
		0x00, 0x73, 0xC0, 	/*  [         ***  ****  ]  */
		0x00, 0x73, 0xC0, 	/*  [         ***  ****  ]  */
		0x00, 0x73, 0xC0, 	/*  [         ***  ****  ]  */
		0x00, 0x77, 0x80, 	/*  [         *** ****   ]  */
		0x0E, 0x7F, 0x80, 	/*  [    ***  ********   ]  */
		0x0F, 0xFF, 0x00, 	/*  [    ************    ]  */
		0x03, 0xFC, 0x00, 	/*  [      ********      ]  */
		0x00, 0x70, 0x00, 	/*  [         ***        ]  */
		0x00, 0x70, 0x00, 	/*  [         ***        ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '%' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x3F, 0x00, 0x70, 	/*  [  ******         ***]  */
		0x7F, 0x80, 0xE0, 	/*  [ ********       *** ]  */
		0x73, 0x81, 0xC0, 	/*  [ ***  ***      ***  ]  */
		0xE1, 0xC3, 0x80, 	/*  [***    ***    ***   ]  */
		0xE1, 0xC3, 0x80, 	/*  [***    ***    ***   ]  */
		0xE1, 0xC7, 0x00, 	/*  [***    ***   ***    ]  */
		0xE1, 0xCE, 0x00, 	/*  [***    ***  ***     ]  */
		0xE1, 0xDC, 0x00, 	/*  [***    *** ***      ]  */
		0x73, 0x9C, 0x00, 	/*  [ ***  ***  ***      ]  */
		0x7F, 0xB8, 0x00, 	/*  [ ******** ***       ]  */
		0x3F, 0x70, 0x00, 	/*  [  ****** ***        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xEF, 0xC0, 	/*  [        *** ******  ]  */
		0x01, 0xDF, 0xE0, 	/*  [       *** ******** ]  */
		0x03, 0x9C, 0xE0, 	/*  [      ***  ***  *** ]  */
		0x03, 0xB8, 0x70, 	/*  [      *** ***    ***]  */
		0x07, 0x38, 0x70, 	/*  [     ***  ***    ***]  */
		0x0E, 0x38, 0x70, 	/*  [    ***   ***    ***]  */
		0x1C, 0x38, 0x70, 	/*  [   ***    ***    ***]  */
		0x1C, 0x38, 0x70, 	/*  [   ***    ***    ***]  */
		0x38, 0x1C, 0xE0, 	/*  [  ***      ***  *** ]  */
		0x70, 0x1F, 0xE0, 	/*  [ ***       ******** ]  */
		0xE0, 0x0F, 0xC0, 	/*  [***         ******  ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '&' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x07, 0xFC, 0x00, 	/*  [     *********      ]  */
		0x07, 0xBE, 0x00, 	/*  [     **** *****     ]  */
		0x0F, 0x1E, 0x00, 	/*  [    ****   ****     ]  */
		0x0F, 0x1E, 0x00, 	/*  [    ****   ****     ]  */
		0x0F, 0x1E, 0x00, 	/*  [    ****   ****     ]  */
		0x0F, 0x3C, 0x00, 	/*  [    ****  ****      ]  */
		0x07, 0xFC, 0x00, 	/*  [     *********      ]  */
		0x07, 0xF8, 0x00, 	/*  [     ********       ]  */
		0x07, 0xE0, 0x00, 	/*  [     ******         ]  */
		0x0F, 0xC0, 0x00, 	/*  [    ******          ]  */
		0x3F, 0xE0, 0xF0, 	/*  [  *********     ****]  */
		0x7D, 0xE0, 0xF0, 	/*  [ ***** ****     ****]  */
		0x79, 0xF0, 0xF0, 	/*  [ ****  *****    ****]  */
		0xF0, 0xF8, 0xE0, 	/*  [****    *****   *** ]  */
		0xF0, 0x78, 0xE0, 	/*  [****     ****   *** ]  */
		0xF0, 0x7D, 0xE0, 	/*  [****     ***** **** ]  */
		0xF0, 0x3F, 0xC0, 	/*  [****      ********  ]  */
		0xF8, 0x1F, 0xC0, 	/*  [*****      *******  ]  */
		0x7C, 0x0F, 0x80, 	/*  [ *****      *****   ]  */
		0x3E, 0x1F, 0xC0, 	/*  [  *****    *******  ]  */
		0x1F, 0xFF, 0xE0, 	/*  [   **************** ]  */
		0x07, 0xF3, 0xF0, 	/*  [     *******  ******]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* ''' charwidth: 20 */
		0x01, 0xF0, 0x00, 	/*  [       *****        ]  */
		0x01, 0xF0, 0x00, 	/*  [       *****        ]  */
		0x01, 0xF0, 0x00, 	/*  [       *****        ]  */
		0x01, 0xF0, 0x00, 	/*  [       *****        ]  */
		0x01, 0xF0, 0x00, 	/*  [       *****        ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '(' charwidth: 20 */
		0x00, 0x01, 0xC0, 	/*  [               ***  ]  */
		0x00, 0x0F, 0xC0, 	/*  [            ******  ]  */
		0x00, 0x1F, 0x00, 	/*  [           *****    ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x03, 0x80, 0x00, 	/*  [      ***           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x03, 0x80, 0x00, 	/*  [      ***           ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x1F, 0x00, 	/*  [           *****    ]  */
		0x00, 0x0F, 0xC0, 	/*  [            ******  ]  */
		0x00, 0x01, 0xC0, 	/*  [               ***  ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* ')' charwidth: 20 */
		0x38, 0x00, 0x00, 	/*  [  ***               ]  */
		0x3F, 0x00, 0x00, 	/*  [  ******            ]  */
		0x0F, 0x80, 0x00, 	/*  [    *****           ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x1C, 0x00, 	/*  [           ***      ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1C, 0x00, 	/*  [           ***      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x0F, 0x80, 0x00, 	/*  [    *****           ]  */
		0x3F, 0x00, 0x00, 	/*  [  ******            ]  */
		0x38, 0x00, 0x00, 	/*  [  ***               ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '*' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x0C, 0x79, 0x80, 	/*  [    **   ****  **   ]  */
		0x0F, 0x37, 0x80, 	/*  [    ****  ** ****   ]  */
		0x1F, 0xDF, 0xC0, 	/*  [   ******* *******  ]  */
		0x07, 0x8F, 0x00, 	/*  [     ****   ****    ]  */
		0x01, 0x98, 0x00, 	/*  [       **  **       ]  */
		0x01, 0xFC, 0x00, 	/*  [       *******      ]  */
		0x01, 0xDC, 0x00, 	/*  [       *** ***      ]  */
		0x03, 0xDE, 0x00, 	/*  [      **** ****     ]  */
		0x07, 0x8F, 0x00, 	/*  [     ****   ****    ]  */
		0x01, 0x8C, 0x00, 	/*  [       **   **      ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '+' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x7F, 0xFF, 0xC0, 	/*  [ *****************  ]  */
		0x7F, 0xFF, 0xC0, 	/*  [ *****************  ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* ',' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x01, 0xF0, 0x00, 	/*  [       *****        ]  */
		0x01, 0xF0, 0x00, 	/*  [       *****        ]  */
		0x01, 0xF0, 0x00, 	/*  [       *****        ]  */
		0x01, 0xF0, 0x00, 	/*  [       *****        ]  */
		0x01, 0xF0, 0x00, 	/*  [       *****        ]  */
		0x00, 0x70, 0x00, 	/*  [         ***        ]  */
		0x00, 0x70, 0x00, 	/*  [         ***        ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xC0, 0x00, 	/*  [       ***          ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '-' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x1F, 0xFF, 0x80, 	/*  [   **************   ]  */
		0x1F, 0xFF, 0x80, 	/*  [   **************   ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '.' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '/' charwidth: 20 */
		0x00, 0x01, 0xE0, 	/*  [               **** ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x0F, 0x00, 	/*  [            ****    ]  */
		0x00, 0x0F, 0x00, 	/*  [            ****    ]  */
		0x00, 0x1F, 0x00, 	/*  [           *****    ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x0F, 0x80, 0x00, 	/*  [    *****           ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x3C, 0x00, 0x00, 	/*  [  ****              ]  */
		0x3C, 0x00, 0x00, 	/*  [  ****              ]  */
		0x78, 0x00, 0x00, 	/*  [ ****               ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '0' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x01, 0xFC, 0x00, 	/*  [       *******      ]  */
		0x03, 0xFE, 0x00, 	/*  [      *********     ]  */
		0x07, 0x8F, 0x00, 	/*  [     ****   ****    ]  */
		0x0F, 0x07, 0x80, 	/*  [    ****     ****   ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1C, 0x01, 0xC0, 	/*  [   ***         ***  ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x1C, 0x01, 0xC0, 	/*  [   ***         ***  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x0F, 0x07, 0x80, 	/*  [    ****     ****   ]  */
		0x07, 0x8F, 0x00, 	/*  [     ****   ****    ]  */
		0x03, 0xFE, 0x00, 	/*  [      *********     ]  */
		0x01, 0xFC, 0x00, 	/*  [       *******      ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '1' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x38, 0x00, 	/*  [          ***       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x0F, 0xF8, 0x00, 	/*  [    *********       ]  */
		0x1F, 0xF8, 0x00, 	/*  [   **********       ]  */
		0x18, 0x78, 0x00, 	/*  [   **    ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x1F, 0xFF, 0xE0, 	/*  [   **************** ]  */
		0x1F, 0xFF, 0xE0, 	/*  [   **************** ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '2' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x03, 0xF8, 0x00, 	/*  [      *******       ]  */
		0x0F, 0xFE, 0x00, 	/*  [    ***********     ]  */
		0x0E, 0x1F, 0x00, 	/*  [    ***    *****    ]  */
		0x00, 0x0F, 0x00, 	/*  [            ****    ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x0F, 0x00, 	/*  [            ****    ]  */
		0x00, 0x1F, 0x00, 	/*  [           *****    ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x0F, 0x80, 0x00, 	/*  [    *****           ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x1F, 0x00, 0x00, 	/*  [   *****            ]  */
		0x1F, 0xFF, 0x80, 	/*  [   **************   ]  */
		0x1F, 0xFF, 0x80, 	/*  [   **************   ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '3' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x07, 0xFC, 0x00, 	/*  [     *********      ]  */
		0x0F, 0xFE, 0x00, 	/*  [    ***********     ]  */
		0x0E, 0x1F, 0x00, 	/*  [    ***    *****    ]  */
		0x00, 0x0F, 0x80, 	/*  [            *****   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x0F, 0x00, 	/*  [            ****    ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x03, 0xFC, 0x00, 	/*  [      ********      ]  */
		0x03, 0xFE, 0x00, 	/*  [      *********     ]  */
		0x00, 0x1F, 0x00, 	/*  [           *****    ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x0E, 0x0F, 0x80, 	/*  [    ***     *****   ]  */
		0x0F, 0xFE, 0x00, 	/*  [    ***********     ]  */
		0x0F, 0xF8, 0x00, 	/*  [    *********       ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '4' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x3E, 0x00, 	/*  [          *****     ]  */
		0x00, 0x7E, 0x00, 	/*  [         ******     ]  */
		0x00, 0x7E, 0x00, 	/*  [         ******     ]  */
		0x00, 0xFE, 0x00, 	/*  [        *******     ]  */
		0x01, 0xFE, 0x00, 	/*  [       ********     ]  */
		0x03, 0xDE, 0x00, 	/*  [      **** ****     ]  */
		0x03, 0xDE, 0x00, 	/*  [      **** ****     ]  */
		0x07, 0x9E, 0x00, 	/*  [     ****  ****     ]  */
		0x0F, 0x1E, 0x00, 	/*  [    ****   ****     ]  */
		0x0F, 0x1E, 0x00, 	/*  [    ****   ****     ]  */
		0x1E, 0x1E, 0x00, 	/*  [   ****    ****     ]  */
		0x3C, 0x1E, 0x00, 	/*  [  ****     ****     ]  */
		0x3C, 0x1E, 0x00, 	/*  [  ****     ****     ]  */
		0x78, 0x1E, 0x00, 	/*  [ ****      ****     ]  */
		0x7F, 0xFF, 0xC0, 	/*  [ *****************  ]  */
		0x7F, 0xFF, 0xC0, 	/*  [ *****************  ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '5' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x07, 0xFF, 0x00, 	/*  [     ***********    ]  */
		0x07, 0xFF, 0x00, 	/*  [     ***********    ]  */
		0x07, 0xFF, 0x00, 	/*  [     ***********    ]  */
		0x07, 0x00, 0x00, 	/*  [     ***            ]  */
		0x07, 0x00, 0x00, 	/*  [     ***            ]  */
		0x07, 0x00, 0x00, 	/*  [     ***            ]  */
		0x07, 0x00, 0x00, 	/*  [     ***            ]  */
		0x07, 0x00, 0x00, 	/*  [     ***            ]  */
		0x07, 0x00, 0x00, 	/*  [     ***            ]  */
		0x07, 0xF0, 0x00, 	/*  [     *******        ]  */
		0x07, 0xFC, 0x00, 	/*  [     *********      ]  */
		0x00, 0x3E, 0x00, 	/*  [          *****     ]  */
		0x00, 0x0F, 0x00, 	/*  [            ****    ]  */
		0x00, 0x0F, 0x80, 	/*  [            *****   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x0F, 0x00, 	/*  [            ****    ]  */
		0x06, 0x1F, 0x00, 	/*  [     **    *****    ]  */
		0x07, 0xFC, 0x00, 	/*  [     *********      ]  */
		0x07, 0xF8, 0x00, 	/*  [     ********       ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '6' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x7F, 0x80, 	/*  [         ********   ]  */
		0x01, 0xFF, 0xC0, 	/*  [       ***********  ]  */
		0x03, 0xE1, 0xC0, 	/*  [      *****    ***  ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0E, 0x00, 0x00, 	/*  [    ***             ]  */
		0x1E, 0x7E, 0x00, 	/*  [   ****  ******     ]  */
		0x1F, 0xFF, 0x80, 	/*  [   **************   ]  */
		0x1F, 0xC7, 0x80, 	/*  [   *******   ****   ]  */
		0x1F, 0x03, 0xC0, 	/*  [   *****      ****  ]  */
		0x1F, 0x03, 0xE0, 	/*  [   *****      ***** ]  */
		0x1F, 0x01, 0xE0, 	/*  [   *****       **** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x0F, 0x01, 0xE0, 	/*  [    ****       **** ]  */
		0x0F, 0x03, 0xC0, 	/*  [    ****      ****  ]  */
		0x07, 0x83, 0xC0, 	/*  [     ****     ****  ]  */
		0x07, 0xC7, 0x80, 	/*  [     *****   ****   ]  */
		0x03, 0xFF, 0x00, 	/*  [      **********    ]  */
		0x00, 0xFC, 0x00, 	/*  [        ******      ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '7' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x1F, 0xFF, 0xC0, 	/*  [   ***************  ]  */
		0x1F, 0xFF, 0xC0, 	/*  [   ***************  ]  */
		0x1F, 0xFF, 0xC0, 	/*  [   ***************  ]  */
		0x00, 0x03, 0x80, 	/*  [              ***   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x07, 0x00, 	/*  [             ***    ]  */
		0x00, 0x0F, 0x00, 	/*  [            ****    ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1C, 0x00, 	/*  [           ***      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x38, 0x00, 	/*  [          ***       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xC0, 0x00, 	/*  [       ***          ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x0F, 0x80, 0x00, 	/*  [    *****           ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '8' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0xFE, 0x00, 	/*  [        *******     ]  */
		0x03, 0xFF, 0x80, 	/*  [      ***********   ]  */
		0x07, 0x87, 0x80, 	/*  [     ****    ****   ]  */
		0x0F, 0x03, 0xC0, 	/*  [    ****      ****  ]  */
		0x0F, 0x03, 0xC0, 	/*  [    ****      ****  ]  */
		0x0F, 0x03, 0xC0, 	/*  [    ****      ****  ]  */
		0x0F, 0x03, 0xC0, 	/*  [    ****      ****  ]  */
		0x0F, 0x87, 0x80, 	/*  [    *****    ****   ]  */
		0x07, 0xCF, 0x00, 	/*  [     *****  ****    ]  */
		0x03, 0xFE, 0x00, 	/*  [      *********     ]  */
		0x01, 0xFC, 0x00, 	/*  [       *******      ]  */
		0x03, 0xFF, 0x00, 	/*  [      **********    ]  */
		0x07, 0x9F, 0x80, 	/*  [     ****  ******   ]  */
		0x0F, 0x0F, 0xC0, 	/*  [    ****    ******  ]  */
		0x1F, 0x03, 0xE0, 	/*  [   *****      ***** ]  */
		0x1E, 0x03, 0xE0, 	/*  [   ****       ***** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x0F, 0x03, 0xC0, 	/*  [    ****      ****  ]  */
		0x0F, 0x87, 0xC0, 	/*  [    *****    *****  ]  */
		0x07, 0xFF, 0x00, 	/*  [     ***********    ]  */
		0x01, 0xFE, 0x00, 	/*  [       ********     ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '9' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x07, 0xFE, 0x00, 	/*  [     **********     ]  */
		0x0F, 0x1F, 0x00, 	/*  [    ****   *****    ]  */
		0x1E, 0x0F, 0x00, 	/*  [   ****     ****    ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x3C, 0x07, 0x80, 	/*  [  ****       ****   ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x07, 0xC0, 	/*  [  ****       *****  ]  */
		0x3E, 0x07, 0xC0, 	/*  [  *****      *****  ]  */
		0x1E, 0x07, 0xC0, 	/*  [   ****      *****  ]  */
		0x0F, 0x1F, 0xC0, 	/*  [    ****   *******  ]  */
		0x07, 0xFF, 0xC0, 	/*  [     *************  ]  */
		0x03, 0xF3, 0xC0, 	/*  [      ******  ****  ]  */
		0x00, 0x03, 0x80, 	/*  [              ***   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x0F, 0x00, 	/*  [            ****    ]  */
		0x00, 0x0F, 0x00, 	/*  [            ****    ]  */
		0x1C, 0x3E, 0x00, 	/*  [   ***    *****     ]  */
		0x1F, 0xFC, 0x00, 	/*  [   ***********      ]  */
		0x0F, 0xF0, 0x00, 	/*  [    ********        ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* ':' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* ';' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xC0, 0x00, 	/*  [       ***          ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '<' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x60, 	/*  [                 ** ]  */
		0x00, 0x01, 0xE0, 	/*  [               **** ]  */
		0x00, 0x07, 0xE0, 	/*  [             ****** ]  */
		0x00, 0x1F, 0xC0, 	/*  [           *******  ]  */
		0x00, 0x7F, 0x00, 	/*  [         *******    ]  */
		0x01, 0xFC, 0x00, 	/*  [       *******      ]  */
		0x07, 0xF0, 0x00, 	/*  [     *******        ]  */
		0x1F, 0x80, 0x00, 	/*  [   ******           ]  */
		0x7E, 0x00, 0x00, 	/*  [ ******             ]  */
		0x1F, 0x80, 0x00, 	/*  [   ******           ]  */
		0x07, 0xF0, 0x00, 	/*  [     *******        ]  */
		0x01, 0xFC, 0x00, 	/*  [       *******      ]  */
		0x00, 0x7F, 0x00, 	/*  [         *******    ]  */
		0x00, 0x1F, 0xC0, 	/*  [           *******  ]  */
		0x00, 0x07, 0xE0, 	/*  [             ****** ]  */
		0x00, 0x01, 0xE0, 	/*  [               **** ]  */
		0x00, 0x00, 0x60, 	/*  [                 ** ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '=' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x7F, 0xFF, 0xE0, 	/*  [ ****************** ]  */
		0x7F, 0xFF, 0xE0, 	/*  [ ****************** ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x7F, 0xFF, 0xE0, 	/*  [ ****************** ]  */
		0x7F, 0xFF, 0xE0, 	/*  [ ****************** ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '>' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x60, 0x00, 0x00, 	/*  [ **                 ]  */
		0x78, 0x00, 0x00, 	/*  [ ****               ]  */
		0x7E, 0x00, 0x00, 	/*  [ ******             ]  */
		0x3F, 0x80, 0x00, 	/*  [  *******           ]  */
		0x0F, 0xE0, 0x00, 	/*  [    *******         ]  */
		0x03, 0xF8, 0x00, 	/*  [      *******       ]  */
		0x00, 0xFE, 0x00, 	/*  [        *******     ]  */
		0x00, 0x1F, 0x80, 	/*  [           ******   ]  */
		0x00, 0x07, 0xE0, 	/*  [             ****** ]  */
		0x00, 0x1F, 0x80, 	/*  [           ******   ]  */
		0x00, 0xFE, 0x00, 	/*  [        *******     ]  */
		0x03, 0xF8, 0x00, 	/*  [      *******       ]  */
		0x0F, 0xE0, 0x00, 	/*  [    *******         ]  */
		0x3F, 0x80, 0x00, 	/*  [  *******           ]  */
		0x7E, 0x00, 0x00, 	/*  [ ******             ]  */
		0x78, 0x00, 0x00, 	/*  [ ****               ]  */
		0x60, 0x00, 0x00, 	/*  [ **                 ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '?' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x0F, 0xFC, 0x00, 	/*  [    **********      ]  */
		0x1F, 0xFF, 0x00, 	/*  [   *************    ]  */
		0x1C, 0x0F, 0x80, 	/*  [   ***      *****   ]  */
		0x1C, 0x03, 0xC0, 	/*  [   ***        ****  ]  */
		0x1C, 0x03, 0xC0, 	/*  [   ***        ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x0F, 0x00, 	/*  [            ****    ]  */
		0x00, 0x3E, 0x00, 	/*  [          *****     ]  */
		0x00, 0x7C, 0x00, 	/*  [         *****      ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '@' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0xFE, 0x00, 	/*  [        *******     ]  */
		0x03, 0xFF, 0x00, 	/*  [      **********    ]  */
		0x07, 0x87, 0x80, 	/*  [     ****    ****   ]  */
		0x0F, 0x03, 0xC0, 	/*  [    ****      ****  ]  */
		0x1E, 0x01, 0xC0, 	/*  [   ****        ***  ]  */
		0x3C, 0x1F, 0xC0, 	/*  [  ****     *******  ]  */
		0x38, 0x7F, 0xC0, 	/*  [  ***    *********  ]  */
		0x38, 0x71, 0xC0, 	/*  [  ***    ***   ***  ]  */
		0x70, 0xE1, 0xC0, 	/*  [ ***    ***    ***  ]  */
		0x70, 0xE1, 0xC0, 	/*  [ ***    ***    ***  ]  */
		0x71, 0xC1, 0xC0, 	/*  [ ***   ***     ***  ]  */
		0x71, 0xC3, 0xC0, 	/*  [ ***   ***    ****  ]  */
		0x71, 0xC3, 0xC0, 	/*  [ ***   ***    ****  ]  */
		0x71, 0xC7, 0xC0, 	/*  [ ***   ***   *****  ]  */
		0x71, 0xC7, 0xC0, 	/*  [ ***   ***   *****  ]  */
		0x71, 0xEF, 0xC0, 	/*  [ ***   **** ******  ]  */
		0x38, 0xFD, 0xF0, 	/*  [  ***   ****** *****]  */
		0x38, 0x79, 0xF0, 	/*  [  ***    ****  *****]  */
		0x3C, 0x00, 0x00, 	/*  [  ****              ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x0F, 0x07, 0x00, 	/*  [    ****     ***    ]  */
		0x07, 0xFF, 0x00, 	/*  [     ***********    ]  */
		0x01, 0xFC, 0x00, 	/*  [       *******      ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'A' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x03, 0xFC, 0x00, 	/*  [      ********      ]  */
		0x03, 0xBC, 0x00, 	/*  [      *** ****      ]  */
		0x07, 0x9E, 0x00, 	/*  [     ****  ****     ]  */
		0x07, 0x9E, 0x00, 	/*  [     ****  ****     ]  */
		0x07, 0x1E, 0x00, 	/*  [     ***   ****     ]  */
		0x0F, 0x0F, 0x00, 	/*  [    ****    ****    ]  */
		0x0F, 0x0F, 0x00, 	/*  [    ****    ****    ]  */
		0x1E, 0x0F, 0x80, 	/*  [   ****     *****   ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x1F, 0xFF, 0x80, 	/*  [   **************   ]  */
		0x3F, 0xFF, 0xC0, 	/*  [  ****************  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x78, 0x03, 0xE0, 	/*  [ ****         ***** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0xF0, 0x00, 0xF0, 	/*  [****            ****]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'B' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x1F, 0xFC, 0x00, 	/*  [   ***********      ]  */
		0x1F, 0xFF, 0x00, 	/*  [   *************    ]  */
		0x1E, 0x0F, 0x00, 	/*  [   ****     ****    ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x1E, 0x0F, 0x00, 	/*  [   ****     ****    ]  */
		0x1E, 0x1E, 0x00, 	/*  [   ****    ****     ]  */
		0x1F, 0xFC, 0x00, 	/*  [   ***********      ]  */
		0x1F, 0xFC, 0x00, 	/*  [   ***********      ]  */
		0x1E, 0x1F, 0x00, 	/*  [   ****    *****    ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x1F, 0xFF, 0x80, 	/*  [   **************   ]  */
		0x1F, 0xFE, 0x00, 	/*  [   ************     ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'C' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x7F, 0xC0, 	/*  [         *********  ]  */
		0x01, 0xFF, 0xE0, 	/*  [       ************ ]  */
		0x07, 0xC0, 0xE0, 	/*  [     *****      *** ]  */
		0x0F, 0x80, 0x00, 	/*  [    *****           ]  */
		0x1F, 0x00, 0x00, 	/*  [   *****            ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x3C, 0x00, 0x00, 	/*  [  ****              ]  */
		0x3C, 0x00, 0x00, 	/*  [  ****              ]  */
		0x3C, 0x00, 0x00, 	/*  [  ****              ]  */
		0x3C, 0x00, 0x00, 	/*  [  ****              ]  */
		0x3C, 0x00, 0x00, 	/*  [  ****              ]  */
		0x3C, 0x00, 0x00, 	/*  [  ****              ]  */
		0x3E, 0x00, 0x00, 	/*  [  *****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1F, 0x00, 0x00, 	/*  [   *****            ]  */
		0x0F, 0x80, 0x00, 	/*  [    *****           ]  */
		0x07, 0xE0, 0xE0, 	/*  [     ******     *** ]  */
		0x03, 0xFF, 0xE0, 	/*  [      ************* ]  */
		0x00, 0x7F, 0xC0, 	/*  [         *********  ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'D' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x3F, 0xF8, 0x00, 	/*  [  ***********       ]  */
		0x3F, 0xFE, 0x00, 	/*  [  *************     ]  */
		0x3C, 0x1F, 0x80, 	/*  [  ****     ******   ]  */
		0x3C, 0x07, 0x80, 	/*  [  ****       ****   ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xC0, 	/*  [  ****         ***  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x07, 0x80, 	/*  [  ****       ****   ]  */
		0x3C, 0x1F, 0x00, 	/*  [  ****     *****    ]  */
		0x3F, 0xFE, 0x00, 	/*  [  *************     ]  */
		0x3F, 0xF8, 0x00, 	/*  [  ***********       ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'E' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x1F, 0xFF, 0x80, 	/*  [   **************   ]  */
		0x1F, 0xFF, 0x80, 	/*  [   **************   ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1F, 0xFF, 0x00, 	/*  [   *************    ]  */
		0x1F, 0xFF, 0x00, 	/*  [   *************    ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1F, 0xFF, 0xC0, 	/*  [   ***************  ]  */
		0x1F, 0xFF, 0xC0, 	/*  [   ***************  ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'F' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x0F, 0xFF, 0xE0, 	/*  [    *************** ]  */
		0x0F, 0xFF, 0xE0, 	/*  [    *************** ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0xFF, 0x80, 	/*  [    *************   ]  */
		0x0F, 0xFF, 0x80, 	/*  [    *************   ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'G' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0xFF, 0x80, 	/*  [        *********   ]  */
		0x03, 0xFF, 0xC0, 	/*  [      ************  ]  */
		0x0F, 0x81, 0xC0, 	/*  [    *****      ***  ]  */
		0x1F, 0x00, 0x00, 	/*  [   *****            ]  */
		0x3E, 0x00, 0x00, 	/*  [  *****             ]  */
		0x3C, 0x00, 0x00, 	/*  [  ****              ]  */
		0x3C, 0x00, 0x00, 	/*  [  ****              ]  */
		0x78, 0x00, 0x00, 	/*  [ ****               ]  */
		0x78, 0x00, 0x00, 	/*  [ ****               ]  */
		0x78, 0x00, 0x00, 	/*  [ ****               ]  */
		0x78, 0x3F, 0xC0, 	/*  [ ****     ********  ]  */
		0x78, 0x3F, 0xC0, 	/*  [ ****     ********  ]  */
		0x78, 0x03, 0xC0, 	/*  [ ****         ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3E, 0x03, 0xC0, 	/*  [  *****       ****  ]  */
		0x1F, 0x03, 0xC0, 	/*  [   *****      ****  ]  */
		0x0F, 0xC3, 0xC0, 	/*  [    ******    ****  ]  */
		0x07, 0xFF, 0xC0, 	/*  [     *************  ]  */
		0x00, 0xFF, 0x00, 	/*  [        ********    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'H' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3F, 0xFF, 0xC0, 	/*  [  ****************  ]  */
		0x3F, 0xFF, 0xC0, 	/*  [  ****************  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'I' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x1F, 0xFF, 0x80, 	/*  [   **************   ]  */
		0x1F, 0xFF, 0x80, 	/*  [   **************   ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x1F, 0xFF, 0x80, 	/*  [   **************   ]  */
		0x1F, 0xFF, 0x80, 	/*  [   **************   ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'J' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x0F, 0xFE, 0x00, 	/*  [    ***********     ]  */
		0x0F, 0xFE, 0x00, 	/*  [    ***********     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x1C, 0x7C, 0x00, 	/*  [   ***   *****      ]  */
		0x1F, 0xF8, 0x00, 	/*  [   **********       ]  */
		0x0F, 0xE0, 0x00, 	/*  [    *******         ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'K' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x1E, 0x0F, 0x80, 	/*  [   ****     *****   ]  */
		0x1E, 0x1F, 0x00, 	/*  [   ****    *****    ]  */
		0x1E, 0x1E, 0x00, 	/*  [   ****    ****     ]  */
		0x1E, 0x3C, 0x00, 	/*  [   ****   ****      ]  */
		0x1E, 0x7C, 0x00, 	/*  [   ****  *****      ]  */
		0x1E, 0x78, 0x00, 	/*  [   ****  ****       ]  */
		0x1E, 0xF0, 0x00, 	/*  [   **** ****        ]  */
		0x1F, 0xF0, 0x00, 	/*  [   *********        ]  */
		0x1F, 0xE0, 0x00, 	/*  [   ********         ]  */
		0x1F, 0xC0, 0x00, 	/*  [   *******          ]  */
		0x1F, 0xE0, 0x00, 	/*  [   ********         ]  */
		0x1F, 0xF0, 0x00, 	/*  [   *********        ]  */
		0x1E, 0xF8, 0x00, 	/*  [   **** *****       ]  */
		0x1E, 0x7C, 0x00, 	/*  [   ****  *****      ]  */
		0x1E, 0x3C, 0x00, 	/*  [   ****   ****      ]  */
		0x1E, 0x1E, 0x00, 	/*  [   ****    ****     ]  */
		0x1E, 0x1F, 0x00, 	/*  [   ****    *****    ]  */
		0x1E, 0x0F, 0x80, 	/*  [   ****     *****   ]  */
		0x1E, 0x07, 0xC0, 	/*  [   ****      *****  ]  */
		0x1E, 0x03, 0xE0, 	/*  [   ****       ***** ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'L' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1F, 0xFF, 0xC0, 	/*  [   ***************  ]  */
		0x1F, 0xFF, 0xC0, 	/*  [   ***************  ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'M' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x7E, 0x03, 0xE0, 	/*  [ ******       ***** ]  */
		0x7E, 0x07, 0xE0, 	/*  [ ******      ****** ]  */
		0x7E, 0x07, 0xE0, 	/*  [ ******      ****** ]  */
		0x7F, 0x07, 0xE0, 	/*  [ *******     ****** ]  */
		0x7F, 0x0F, 0xE0, 	/*  [ *******    ******* ]  */
		0x7F, 0x0F, 0xE0, 	/*  [ *******    ******* ]  */
		0x7F, 0x8F, 0xE0, 	/*  [ ********   ******* ]  */
		0x7F, 0x9D, 0xE0, 	/*  [ ********  *** **** ]  */
		0x7B, 0x9D, 0xE0, 	/*  [ **** ***  *** **** ]  */
		0x7B, 0xDD, 0xE0, 	/*  [ **** **** *** **** ]  */
		0x7B, 0xF9, 0xE0, 	/*  [ **** *******  **** ]  */
		0x79, 0xF9, 0xE0, 	/*  [ ****  ******  **** ]  */
		0x79, 0xF9, 0xE0, 	/*  [ ****  ******  **** ]  */
		0x79, 0xF9, 0xE0, 	/*  [ ****  ******  **** ]  */
		0x78, 0xF1, 0xE0, 	/*  [ ****   ****   **** ]  */
		0x78, 0xF1, 0xE0, 	/*  [ ****   ****   **** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'N' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x3E, 0x03, 0xC0, 	/*  [  *****       ****  ]  */
		0x3E, 0x03, 0xC0, 	/*  [  *****       ****  ]  */
		0x3F, 0x03, 0xC0, 	/*  [  ******      ****  ]  */
		0x3F, 0x03, 0xC0, 	/*  [  ******      ****  ]  */
		0x3F, 0x83, 0xC0, 	/*  [  *******     ****  ]  */
		0x3F, 0xC3, 0xC0, 	/*  [  ********    ****  ]  */
		0x3F, 0xC3, 0xC0, 	/*  [  ********    ****  ]  */
		0x3F, 0xE3, 0xC0, 	/*  [  *********   ****  ]  */
		0x3D, 0xE3, 0xC0, 	/*  [  **** ****   ****  ]  */
		0x3C, 0xF3, 0xC0, 	/*  [  ****  ****  ****  ]  */
		0x3C, 0xFB, 0xC0, 	/*  [  ****  ***** ****  ]  */
		0x3C, 0x7B, 0xC0, 	/*  [  ****   **** ****  ]  */
		0x3C, 0x7F, 0xC0, 	/*  [  ****   *********  ]  */
		0x3C, 0x3F, 0xC0, 	/*  [  ****    ********  ]  */
		0x3C, 0x3F, 0xC0, 	/*  [  ****    ********  ]  */
		0x3C, 0x1F, 0xC0, 	/*  [  ****     *******  ]  */
		0x3C, 0x0F, 0xC0, 	/*  [  ****      ******  ]  */
		0x3C, 0x0F, 0xC0, 	/*  [  ****      ******  ]  */
		0x3C, 0x07, 0xC0, 	/*  [  ****       *****  ]  */
		0x3C, 0x07, 0xC0, 	/*  [  ****       *****  ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'O' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x03, 0xFC, 0x00, 	/*  [      ********      ]  */
		0x07, 0xFE, 0x00, 	/*  [     **********     ]  */
		0x1F, 0x0F, 0x80, 	/*  [   *****    *****   ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x0F, 0x0F, 0x80, 	/*  [    ****    *****   ]  */
		0x07, 0xFE, 0x00, 	/*  [     **********     ]  */
		0x03, 0xFC, 0x00, 	/*  [      ********      ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'P' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x0F, 0xFF, 0x00, 	/*  [    ************    ]  */
		0x0F, 0xFF, 0x80, 	/*  [    *************   ]  */
		0x0F, 0x07, 0xC0, 	/*  [    ****     *****  ]  */
		0x0F, 0x01, 0xE0, 	/*  [    ****       **** ]  */
		0x0F, 0x01, 0xE0, 	/*  [    ****       **** ]  */
		0x0F, 0x01, 0xE0, 	/*  [    ****       **** ]  */
		0x0F, 0x01, 0xE0, 	/*  [    ****       **** ]  */
		0x0F, 0x01, 0xE0, 	/*  [    ****       **** ]  */
		0x0F, 0x03, 0xC0, 	/*  [    ****      ****  ]  */
		0x0F, 0x0F, 0xC0, 	/*  [    ****    ******  ]  */
		0x0F, 0xFF, 0x00, 	/*  [    ************    ]  */
		0x0F, 0xFC, 0x00, 	/*  [    **********      ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'Q' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x03, 0xFC, 0x00, 	/*  [      ********      ]  */
		0x07, 0xFE, 0x00, 	/*  [     **********     ]  */
		0x1F, 0x0F, 0x80, 	/*  [   *****    *****   ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x0F, 0x0F, 0x80, 	/*  [    ****    *****   ]  */
		0x07, 0xFE, 0x00, 	/*  [     **********     ]  */
		0x03, 0xFC, 0x00, 	/*  [      ********      ]  */
		0x00, 0x1F, 0x00, 	/*  [           *****    ]  */
		0x00, 0x0F, 0xC0, 	/*  [            ******  ]  */
		0x00, 0x07, 0xF0, 	/*  [             *******]  */
		0x00, 0x01, 0xE0, 	/*  [               **** ]  */
		0x00, 0x00, 0xE0, 	/*  [                *** ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'R' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x1F, 0xFC, 0x00, 	/*  [   ***********      ]  */
		0x1F, 0xFF, 0x00, 	/*  [   *************    ]  */
		0x1E, 0x1F, 0x00, 	/*  [   ****    *****    ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x1E, 0x0F, 0x00, 	/*  [   ****     ****    ]  */
		0x1E, 0x3E, 0x00, 	/*  [   ****   *****     ]  */
		0x1F, 0xFC, 0x00, 	/*  [   ***********      ]  */
		0x1F, 0xF8, 0x00, 	/*  [   **********       ]  */
		0x1E, 0x7C, 0x00, 	/*  [   ****  *****      ]  */
		0x1E, 0x3E, 0x00, 	/*  [   ****   *****     ]  */
		0x1E, 0x1F, 0x00, 	/*  [   ****    *****    ]  */
		0x1E, 0x0F, 0x00, 	/*  [   ****     ****    ]  */
		0x1E, 0x0F, 0x80, 	/*  [   ****     *****   ]  */
		0x1E, 0x07, 0xC0, 	/*  [   ****      *****  ]  */
		0x1E, 0x03, 0xE0, 	/*  [   ****       ***** ]  */
		0x1E, 0x01, 0xF0, 	/*  [   ****        *****]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'S' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x01, 0xFF, 0x00, 	/*  [       *********    ]  */
		0x07, 0xFF, 0xC0, 	/*  [     *************  ]  */
		0x0F, 0x83, 0xC0, 	/*  [    *****     ****  ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1F, 0x00, 0x00, 	/*  [   *****            ]  */
		0x1F, 0x80, 0x00, 	/*  [   ******           ]  */
		0x0F, 0xF0, 0x00, 	/*  [    ********        ]  */
		0x03, 0xFE, 0x00, 	/*  [      *********     ]  */
		0x00, 0xFF, 0x80, 	/*  [        *********   ]  */
		0x00, 0x1F, 0xC0, 	/*  [           *******  ]  */
		0x00, 0x03, 0xE0, 	/*  [              ***** ]  */
		0x00, 0x01, 0xE0, 	/*  [               **** ]  */
		0x00, 0x01, 0xE0, 	/*  [               **** ]  */
		0x00, 0x01, 0xE0, 	/*  [               **** ]  */
		0x18, 0x03, 0xC0, 	/*  [   **         ****  ]  */
		0x1F, 0x07, 0xC0, 	/*  [   *****     *****  ]  */
		0x1F, 0xFF, 0x80, 	/*  [   **************   ]  */
		0x07, 0xFC, 0x00, 	/*  [     *********      ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'T' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0xFF, 0xFF, 0xF0, 	/*  [********************]  */
		0xFF, 0xFF, 0xF0, 	/*  [********************]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'U' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x07, 0xC0, 	/*  [  ****       *****  ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x1F, 0x0F, 0x00, 	/*  [   *****    ****    ]  */
		0x0F, 0xFE, 0x00, 	/*  [    ***********     ]  */
		0x03, 0xFC, 0x00, 	/*  [      ********      ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'V' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0xF0, 0x00, 0xF0, 	/*  [****            ****]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x7C, 0x03, 0xE0, 	/*  [ *****        ***** ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x1F, 0x07, 0x80, 	/*  [   *****     ****   ]  */
		0x0F, 0x0F, 0x00, 	/*  [    ****    ****    ]  */
		0x0F, 0x8F, 0x00, 	/*  [    *****   ****    ]  */
		0x07, 0x9E, 0x00, 	/*  [     ****  ****     ]  */
		0x07, 0x9E, 0x00, 	/*  [     ****  ****     ]  */
		0x07, 0xDE, 0x00, 	/*  [     ***** ****     ]  */
		0x03, 0xFC, 0x00, 	/*  [      ********      ]  */
		0x03, 0xFC, 0x00, 	/*  [      ********      ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'W' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0xF0, 0x00, 0x70, 	/*  [****             ***]  */
		0xF0, 0x00, 0xF0, 	/*  [****            ****]  */
		0xF0, 0x00, 0xF0, 	/*  [****            ****]  */
		0x70, 0x00, 0xE0, 	/*  [ ***            *** ]  */
		0x70, 0xF0, 0xE0, 	/*  [ ***    ****    *** ]  */
		0x70, 0xF0, 0xE0, 	/*  [ ***    ****    *** ]  */
		0x78, 0xF8, 0xE0, 	/*  [ ****   *****   *** ]  */
		0x79, 0xF8, 0xE0, 	/*  [ ****  ******   *** ]  */
		0x79, 0xF8, 0xE0, 	/*  [ ****  ******   *** ]  */
		0x79, 0xF9, 0xC0, 	/*  [ ****  ******  ***  ]  */
		0x39, 0xFD, 0xC0, 	/*  [  ***  ******* ***  ]  */
		0x39, 0xFD, 0xC0, 	/*  [  ***  ******* ***  ]  */
		0x3F, 0x9D, 0xC0, 	/*  [  *******  *** ***  ]  */
		0x3F, 0x9D, 0xC0, 	/*  [  *******  *** ***  ]  */
		0x3F, 0x9F, 0xC0, 	/*  [  *******  *******  ]  */
		0x3F, 0x9F, 0x80, 	/*  [  *******  ******   ]  */
		0x3F, 0x1F, 0x80, 	/*  [  ******   ******   ]  */
		0x1F, 0x0F, 0x80, 	/*  [   *****    *****   ]  */
		0x1F, 0x0F, 0x80, 	/*  [   *****    *****   ]  */
		0x1F, 0x0F, 0x80, 	/*  [   *****    *****   ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'X' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x7C, 0x01, 0xF0, 	/*  [ *****         *****]  */
		0x3E, 0x03, 0xE0, 	/*  [  *****       ***** ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x0F, 0x07, 0x80, 	/*  [    ****     ****   ]  */
		0x0F, 0x8F, 0x00, 	/*  [    *****   ****    ]  */
		0x07, 0xDE, 0x00, 	/*  [     ***** ****     ]  */
		0x03, 0xDE, 0x00, 	/*  [      **** ****     ]  */
		0x03, 0xFC, 0x00, 	/*  [      ********      ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xFC, 0x00, 	/*  [       *******      ]  */
		0x03, 0xFE, 0x00, 	/*  [      *********     ]  */
		0x07, 0x9E, 0x00, 	/*  [     ****  ****     ]  */
		0x0F, 0x1F, 0x00, 	/*  [    ****   *****    ]  */
		0x1F, 0x0F, 0x80, 	/*  [   *****    *****   ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x78, 0x03, 0xE0, 	/*  [ ****         ***** ]  */
		0xF0, 0x01, 0xF0, 	/*  [****           *****]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'Y' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x7C, 0x00, 0xF0, 	/*  [ *****          ****]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x1F, 0x03, 0xC0, 	/*  [   *****      ****  ]  */
		0x0F, 0x03, 0x80, 	/*  [    ****      ***   ]  */
		0x07, 0x87, 0x80, 	/*  [     ****    ****   ]  */
		0x07, 0xCF, 0x00, 	/*  [     *****  ****    ]  */
		0x03, 0xEF, 0x00, 	/*  [      ***** ****    ]  */
		0x01, 0xFE, 0x00, 	/*  [       ********     ]  */
		0x01, 0xFC, 0x00, 	/*  [       *******      ]  */
		0x00, 0xFC, 0x00, 	/*  [        ******      ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'Z' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x1F, 0xFF, 0xE0, 	/*  [   **************** ]  */
		0x1F, 0xFF, 0xE0, 	/*  [   **************** ]  */
		0x00, 0x03, 0xE0, 	/*  [              ***** ]  */
		0x00, 0x07, 0xC0, 	/*  [             *****  ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x0F, 0x00, 	/*  [            ****    ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x3E, 0x00, 	/*  [          *****     ]  */
		0x00, 0x7C, 0x00, 	/*  [         *****      ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x01, 0xF0, 0x00, 	/*  [       *****        ]  */
		0x03, 0xE0, 0x00, 	/*  [      *****         ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x1F, 0x00, 0x00, 	/*  [   *****            ]  */
		0x3E, 0x00, 0x00, 	/*  [  *****             ]  */
		0x3F, 0xFF, 0xE0, 	/*  [  ***************** ]  */
		0x3F, 0xFF, 0xE0, 	/*  [  ***************** ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '[' charwidth: 20 */
		0x01, 0xFF, 0xC0, 	/*  [       ***********  ]  */
		0x01, 0xFF, 0xC0, 	/*  [       ***********  ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xFF, 0xC0, 	/*  [       ***********  ]  */
		0x01, 0xFF, 0xC0, 	/*  [       ***********  ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '\' charwidth: 20 */
		0x78, 0x00, 0x00, 	/*  [ ****               ]  */
		0x3C, 0x00, 0x00, 	/*  [  ****              ]  */
		0x3C, 0x00, 0x00, 	/*  [  ****              ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x80, 0x00, 	/*  [    *****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1F, 0x00, 	/*  [           *****    ]  */
		0x00, 0x0F, 0x00, 	/*  [            ****    ]  */
		0x00, 0x0F, 0x00, 	/*  [            ****    ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x01, 0xE0, 	/*  [               **** ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* ']' charwidth: 20 */
		0x1F, 0xFC, 0x00, 	/*  [   ***********      ]  */
		0x1F, 0xFC, 0x00, 	/*  [   ***********      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x00, 0x3C, 0x00, 	/*  [          ****      ]  */
		0x1F, 0xFC, 0x00, 	/*  [   ***********      ]  */
		0x1F, 0xFC, 0x00, 	/*  [   ***********      ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '^' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x60, 0x00, 	/*  [         **         ]  */
		0x00, 0x60, 0x00, 	/*  [         **         ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x03, 0xFC, 0x00, 	/*  [      ********      ]  */
		0x03, 0xFC, 0x00, 	/*  [      ********      ]  */
		0x07, 0x9E, 0x00, 	/*  [     ****  ****     ]  */
		0x07, 0x9E, 0x00, 	/*  [     ****  ****     ]  */
		0x07, 0x0E, 0x00, 	/*  [     ***    ***     ]  */
		0x0F, 0x0F, 0x00, 	/*  [    ****    ****    ]  */
		0x0E, 0x07, 0x00, 	/*  [    ***      ***    ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '_' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0xFF, 0xFF, 0xF0, 	/*  [********************]  */
		0xFF, 0xFF, 0xF0, 	/*  [********************]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '`' charwidth: 20 */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0x38, 0x00, 	/*  [          ***       ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'a' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x07, 0xF8, 0x00, 	/*  [     ********       ]  */
		0x1F, 0xFE, 0x00, 	/*  [   ************     ]  */
		0x1C, 0x1F, 0x00, 	/*  [   ***     *****    ]  */
		0x00, 0x0F, 0x00, 	/*  [            ****    ]  */
		0x00, 0x0F, 0x00, 	/*  [            ****    ]  */
		0x00, 0x0F, 0x00, 	/*  [            ****    ]  */
		0x00, 0x0F, 0x00, 	/*  [            ****    ]  */
		0x03, 0xFF, 0x00, 	/*  [      **********    ]  */
		0x0F, 0xFF, 0x00, 	/*  [    ************    ]  */
		0x1F, 0x0F, 0x00, 	/*  [   *****    ****    ]  */
		0x3E, 0x0F, 0x00, 	/*  [  *****     ****    ]  */
		0x3C, 0x0F, 0x00, 	/*  [  ****      ****    ]  */
		0x3C, 0x0F, 0x00, 	/*  [  ****      ****    ]  */
		0x3C, 0x0F, 0x00, 	/*  [  ****      ****    ]  */
		0x3E, 0x3F, 0x00, 	/*  [  *****   ******    ]  */
		0x1F, 0xF7, 0xE0, 	/*  [   ********* ****** ]  */
		0x07, 0xE3, 0xE0, 	/*  [     ******   ***** ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'b' charwidth: 20 */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x7E, 0x00, 	/*  [   ****  ******     ]  */
		0x1E, 0xFF, 0x80, 	/*  [   **** *********   ]  */
		0x1F, 0xC7, 0xC0, 	/*  [   *******   *****  ]  */
		0x1F, 0x83, 0xC0, 	/*  [   ******     ****  ]  */
		0x1F, 0x01, 0xE0, 	/*  [   *****       **** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1F, 0x03, 0xC0, 	/*  [   *****      ****  ]  */
		0x1F, 0x8F, 0x80, 	/*  [   ******   *****   ]  */
		0x1F, 0xFF, 0x00, 	/*  [   *************    ]  */
		0x1C, 0xFC, 0x00, 	/*  [   ***  ******      ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'c' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x7F, 0xC0, 	/*  [         *********  ]  */
		0x03, 0xFF, 0xE0, 	/*  [      ************* ]  */
		0x07, 0xE0, 0xE0, 	/*  [     ******     *** ]  */
		0x0F, 0x80, 0x00, 	/*  [    *****           ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x1F, 0x00, 0x00, 	/*  [   *****            ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1F, 0x00, 0x00, 	/*  [   *****            ]  */
		0x0F, 0x00, 0x00, 	/*  [    ****            ]  */
		0x0F, 0x80, 0x00, 	/*  [    *****           ]  */
		0x07, 0xE0, 0xE0, 	/*  [     ******     *** ]  */
		0x03, 0xFF, 0xE0, 	/*  [      ************* ]  */
		0x00, 0x7F, 0xC0, 	/*  [         *********  ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'd' charwidth: 20 */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x01, 0xFB, 0xC0, 	/*  [       ****** ****  ]  */
		0x07, 0xFF, 0xC0, 	/*  [     *************  ]  */
		0x0F, 0x8F, 0xC0, 	/*  [    *****   ******  ]  */
		0x1E, 0x07, 0xC0, 	/*  [   ****      *****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x07, 0xC0, 	/*  [  ****       *****  ]  */
		0x1E, 0x0F, 0xC0, 	/*  [   ****     ******  ]  */
		0x1F, 0x1F, 0xC0, 	/*  [   *****   *******  ]  */
		0x0F, 0xFB, 0xC0, 	/*  [    ********* ****  ]  */
		0x03, 0xF3, 0xC0, 	/*  [      ******  ****  ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'e' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x01, 0xFC, 0x00, 	/*  [       *******      ]  */
		0x07, 0xFF, 0x00, 	/*  [     ***********    ]  */
		0x0F, 0x8F, 0x80, 	/*  [    *****   *****   ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3F, 0xFF, 0xC0, 	/*  [  ****************  ]  */
		0x3F, 0xFF, 0xC0, 	/*  [  ****************  ]  */
		0x3C, 0x00, 0x00, 	/*  [  ****              ]  */
		0x3C, 0x00, 0x00, 	/*  [  ****              ]  */
		0x3C, 0x00, 0x00, 	/*  [  ****              ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1F, 0x00, 0x00, 	/*  [   *****            ]  */
		0x0F, 0x81, 0xC0, 	/*  [    *****      ***  ]  */
		0x07, 0xFF, 0xC0, 	/*  [     *************  ]  */
		0x01, 0xFF, 0x00, 	/*  [       *********    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'f' charwidth: 20 */
		0x00, 0x3F, 0xF0, 	/*  [          **********]  */
		0x00, 0x7F, 0xF0, 	/*  [         ***********]  */
		0x00, 0xF8, 0x30, 	/*  [        *****     **]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x3F, 0xFF, 0xE0, 	/*  [  ***************** ]  */
		0x3F, 0xFF, 0xE0, 	/*  [  ***************** ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'g' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x01, 0xFB, 0xC0, 	/*  [       ****** ****  ]  */
		0x07, 0xFF, 0xC0, 	/*  [     *************  ]  */
		0x0F, 0x8F, 0xC0, 	/*  [    *****   ******  ]  */
		0x1E, 0x07, 0xC0, 	/*  [   ****      *****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3E, 0x07, 0xC0, 	/*  [  *****      *****  ]  */
		0x1E, 0x0F, 0xC0, 	/*  [   ****     ******  ]  */
		0x1F, 0x1F, 0xC0, 	/*  [   *****   *******  ]  */
		0x0F, 0xFB, 0xC0, 	/*  [    ********* ****  ]  */
		0x03, 0xF3, 0xC0, 	/*  [      ******  ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x03, 0x80, 	/*  [              ***   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x1C, 0x0F, 0x00, 	/*  [   ***      ****    ]  */
		0x1F, 0xFE, 0x00, 	/*  [   ************     ]  */
		0x0F, 0xF8, 0x00, 	/*  [    *********       ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'h' charwidth: 20 */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x7F, 0x00, 	/*  [   ****  *******    ]  */
		0x1E, 0xFF, 0x80, 	/*  [   **** *********   ]  */
		0x1F, 0xC7, 0x80, 	/*  [   *******   ****   ]  */
		0x1F, 0x83, 0xC0, 	/*  [   ******     ****  ]  */
		0x1F, 0x03, 0xC0, 	/*  [   *****      ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'i' charwidth: 20 */
		0x00, 0xF8, 0x00, 	/*  [        *****       ]  */
		0x00, 0xF8, 0x00, 	/*  [        *****       ]  */
		0x00, 0xF8, 0x00, 	/*  [        *****       ]  */
		0x00, 0xF8, 0x00, 	/*  [        *****       ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x1F, 0xF8, 0x00, 	/*  [   **********       ]  */
		0x1F, 0xF8, 0x00, 	/*  [   **********       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'j' charwidth: 20 */
		0x00, 0x3E, 0x00, 	/*  [          *****     ]  */
		0x00, 0x3E, 0x00, 	/*  [          *****     ]  */
		0x00, 0x3E, 0x00, 	/*  [          *****     ]  */
		0x00, 0x3E, 0x00, 	/*  [          *****     ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x0F, 0xFE, 0x00, 	/*  [    ***********     ]  */
		0x0F, 0xFE, 0x00, 	/*  [    ***********     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1E, 0x00, 	/*  [           ****     ]  */
		0x00, 0x1C, 0x00, 	/*  [           ***      ]  */
		0x1C, 0x3C, 0x00, 	/*  [   ***    ****      ]  */
		0x1F, 0xF8, 0x00, 	/*  [   **********       ]  */
		0x0F, 0xF0, 0x00, 	/*  [    ********        ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'k' charwidth: 20 */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x0F, 0xC0, 	/*  [   ****     ******  ]  */
		0x1E, 0x0F, 0x80, 	/*  [   ****     *****   ]  */
		0x1E, 0x1F, 0x00, 	/*  [   ****    *****    ]  */
		0x1E, 0x3E, 0x00, 	/*  [   ****   *****     ]  */
		0x1E, 0x7C, 0x00, 	/*  [   ****  *****      ]  */
		0x1E, 0xF8, 0x00, 	/*  [   **** *****       ]  */
		0x1F, 0xF0, 0x00, 	/*  [   *********        ]  */
		0x1F, 0xE0, 0x00, 	/*  [   ********         ]  */
		0x1F, 0xE0, 0x00, 	/*  [   ********         ]  */
		0x1F, 0xF0, 0x00, 	/*  [   *********        ]  */
		0x1E, 0xF8, 0x00, 	/*  [   **** *****       ]  */
		0x1E, 0x7C, 0x00, 	/*  [   ****  *****      ]  */
		0x1E, 0x3E, 0x00, 	/*  [   ****   *****     ]  */
		0x1E, 0x1F, 0x00, 	/*  [   ****    *****    ]  */
		0x1E, 0x0F, 0x80, 	/*  [   ****     *****   ]  */
		0x1E, 0x07, 0xC0, 	/*  [   ****      *****  ]  */
		0x1E, 0x03, 0xE0, 	/*  [   ****       ***** ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'l' charwidth: 20 */
		0x3F, 0xF8, 0x00, 	/*  [  ***********       ]  */
		0x3F, 0xF8, 0x00, 	/*  [  ***********       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'm' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x7B, 0xC7, 0xC0, 	/*  [ **** ****   *****  ]  */
		0x7F, 0xEF, 0xC0, 	/*  [ ********** ******  ]  */
		0x7F, 0xFF, 0xE0, 	/*  [ ****************** ]  */
		0x7E, 0xFD, 0xE0, 	/*  [ ****** ****** **** ]  */
		0x7C, 0xF9, 0xE0, 	/*  [ *****  *****  **** ]  */
		0x7C, 0xF9, 0xE0, 	/*  [ *****  *****  **** ]  */
		0x78, 0xF1, 0xE0, 	/*  [ ****   ****   **** ]  */
		0x78, 0xF1, 0xE0, 	/*  [ ****   ****   **** ]  */
		0x78, 0xF1, 0xE0, 	/*  [ ****   ****   **** ]  */
		0x78, 0xF1, 0xE0, 	/*  [ ****   ****   **** ]  */
		0x78, 0xF1, 0xE0, 	/*  [ ****   ****   **** ]  */
		0x78, 0xF1, 0xE0, 	/*  [ ****   ****   **** ]  */
		0x78, 0xF1, 0xE0, 	/*  [ ****   ****   **** ]  */
		0x78, 0xF1, 0xE0, 	/*  [ ****   ****   **** ]  */
		0x78, 0xF1, 0xE0, 	/*  [ ****   ****   **** ]  */
		0x78, 0xF1, 0xE0, 	/*  [ ****   ****   **** ]  */
		0x78, 0xF1, 0xE0, 	/*  [ ****   ****   **** ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'n' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x1E, 0x7F, 0x00, 	/*  [   ****  *******    ]  */
		0x1E, 0xFF, 0x80, 	/*  [   **** *********   ]  */
		0x1F, 0xC7, 0x80, 	/*  [   *******   ****   ]  */
		0x1F, 0x83, 0xC0, 	/*  [   ******     ****  ]  */
		0x1F, 0x03, 0xC0, 	/*  [   *****      ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'o' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x01, 0xFC, 0x00, 	/*  [       *******      ]  */
		0x07, 0xFF, 0x00, 	/*  [     ***********    ]  */
		0x0F, 0x8F, 0x80, 	/*  [    *****   *****   ]  */
		0x1F, 0x07, 0xC0, 	/*  [   *****     *****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x3C, 0x01, 0xE0, 	/*  [  ****         **** ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1F, 0x07, 0xC0, 	/*  [   *****     *****  ]  */
		0x0F, 0x8F, 0x80, 	/*  [    *****   *****   ]  */
		0x07, 0xFF, 0x00, 	/*  [     ***********    ]  */
		0x01, 0xFC, 0x00, 	/*  [       *******      ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'p' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x1E, 0x7E, 0x00, 	/*  [   ****  ******     ]  */
		0x1E, 0xFF, 0x80, 	/*  [   **** *********   ]  */
		0x1F, 0xC7, 0xC0, 	/*  [   *******   *****  ]  */
		0x1F, 0x83, 0xC0, 	/*  [   ******     ****  ]  */
		0x1F, 0x01, 0xE0, 	/*  [   *****       **** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x1E, 0x01, 0xE0, 	/*  [   ****        **** ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1F, 0x03, 0xC0, 	/*  [   *****      ****  ]  */
		0x1F, 0x8F, 0x80, 	/*  [   ******   *****   ]  */
		0x1F, 0xFF, 0x00, 	/*  [   *************    ]  */
		0x1E, 0xFC, 0x00, 	/*  [   **** ******      ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'q' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x01, 0xFB, 0xC0, 	/*  [       ****** ****  ]  */
		0x07, 0xFF, 0xC0, 	/*  [     *************  ]  */
		0x0F, 0x8F, 0xC0, 	/*  [    *****   ******  ]  */
		0x1E, 0x07, 0xC0, 	/*  [   ****      *****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x07, 0xC0, 	/*  [  ****       *****  ]  */
		0x1E, 0x0F, 0xC0, 	/*  [   ****     ******  ]  */
		0x1F, 0x1F, 0xC0, 	/*  [   *****   *******  ]  */
		0x0F, 0xFB, 0xC0, 	/*  [    ********* ****  ]  */
		0x03, 0xF3, 0xC0, 	/*  [      ******  ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x03, 0xC0, 	/*  [              ****  ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'r' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x07, 0x8F, 0xE0, 	/*  [     ****   ******* ]  */
		0x07, 0xBF, 0xE0, 	/*  [     **** ********* ]  */
		0x07, 0xF8, 0xE0, 	/*  [     ********   *** ]  */
		0x07, 0xE0, 0xE0, 	/*  [     ******     *** ]  */
		0x07, 0xC0, 0xE0, 	/*  [     *****      *** ]  */
		0x07, 0xC0, 0x00, 	/*  [     *****          ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x07, 0x80, 0x00, 	/*  [     ****           ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 's' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x03, 0xFE, 0x00, 	/*  [      *********     ]  */
		0x0F, 0xFF, 0x00, 	/*  [    ************    ]  */
		0x0F, 0x07, 0x00, 	/*  [    ****     ***    ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1E, 0x00, 0x00, 	/*  [   ****             ]  */
		0x1F, 0x00, 0x00, 	/*  [   *****            ]  */
		0x1F, 0xC0, 0x00, 	/*  [   *******          ]  */
		0x0F, 0xF8, 0x00, 	/*  [    *********       ]  */
		0x03, 0xFE, 0x00, 	/*  [      *********     ]  */
		0x00, 0x7F, 0x00, 	/*  [         *******    ]  */
		0x00, 0x0F, 0x80, 	/*  [            *****   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x00, 0x07, 0x80, 	/*  [             ****   ]  */
		0x1E, 0x1F, 0x00, 	/*  [   ****    *****    ]  */
		0x1F, 0xFE, 0x00, 	/*  [   ************     ]  */
		0x07, 0xF8, 0x00, 	/*  [     ********       ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 't' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x3F, 0xFF, 0xC0, 	/*  [  ****************  ]  */
		0x3F, 0xFF, 0xC0, 	/*  [  ****************  ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xFF, 0xC0, 	/*  [       ***********  ]  */
		0x00, 0x7F, 0xC0, 	/*  [         *********  ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'u' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x03, 0xC0, 	/*  [   ****       ****  ]  */
		0x1E, 0x07, 0xC0, 	/*  [   ****      *****  ]  */
		0x1E, 0x07, 0xC0, 	/*  [   ****      *****  ]  */
		0x1E, 0x0F, 0xC0, 	/*  [   ****     ******  ]  */
		0x0F, 0x1F, 0xC0, 	/*  [    ****   *******  ]  */
		0x0F, 0xFB, 0xC0, 	/*  [    ********* ****  ]  */
		0x07, 0xF3, 0xC0, 	/*  [     *******  ****  ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'v' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x78, 0x01, 0xE0, 	/*  [ ****          **** ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x3E, 0x07, 0xC0, 	/*  [  *****      *****  ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x0F, 0x0F, 0x00, 	/*  [    ****    ****    ]  */
		0x0F, 0x0F, 0x00, 	/*  [    ****    ****    ]  */
		0x0F, 0x8F, 0x00, 	/*  [    *****   ****    ]  */
		0x07, 0x9E, 0x00, 	/*  [     ****  ****     ]  */
		0x07, 0x9E, 0x00, 	/*  [     ****  ****     ]  */
		0x03, 0xDC, 0x00, 	/*  [      **** ***      ]  */
		0x03, 0xFC, 0x00, 	/*  [      ********      ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'w' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0xF0, 0x00, 0x70, 	/*  [****             ***]  */
		0xF0, 0x00, 0xF0, 	/*  [****            ****]  */
		0xF0, 0xF0, 0xE0, 	/*  [****    ****    *** ]  */
		0x70, 0xF8, 0xE0, 	/*  [ ***    *****   *** ]  */
		0x78, 0xF8, 0xE0, 	/*  [ ****   *****   *** ]  */
		0x79, 0xF8, 0xE0, 	/*  [ ****  ******   *** ]  */
		0x79, 0xF9, 0xE0, 	/*  [ ****  ******  **** ]  */
		0x79, 0xFD, 0xC0, 	/*  [ ****  ******* ***  ]  */
		0x3B, 0xBD, 0xC0, 	/*  [  *** *** **** ***  ]  */
		0x3B, 0x9D, 0xC0, 	/*  [  *** ***  *** ***  ]  */
		0x3F, 0x9D, 0xC0, 	/*  [  *******  *** ***  ]  */
		0x3F, 0x9D, 0xC0, 	/*  [  *******  *** ***  ]  */
		0x3F, 0x1F, 0x80, 	/*  [  ******   ******   ]  */
		0x3F, 0x0F, 0x80, 	/*  [  ******    *****   ]  */
		0x1F, 0x0F, 0x80, 	/*  [   *****    *****   ]  */
		0x1F, 0x0F, 0x80, 	/*  [   *****    *****   ]  */
		0x1E, 0x0F, 0x80, 	/*  [   ****     *****   ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'x' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x7C, 0x03, 0xC0, 	/*  [ *****        ****  ]  */
		0x3E, 0x07, 0x80, 	/*  [  *****      ****   ]  */
		0x1F, 0x0F, 0x00, 	/*  [   *****    ****    ]  */
		0x0F, 0x8F, 0x00, 	/*  [    *****   ****    ]  */
		0x0F, 0x9E, 0x00, 	/*  [    *****  ****     ]  */
		0x07, 0xFC, 0x00, 	/*  [     *********      ]  */
		0x03, 0xFC, 0x00, 	/*  [      ********      ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF0, 0x00, 	/*  [       *****        ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x03, 0xFC, 0x00, 	/*  [      ********      ]  */
		0x07, 0xBE, 0x00, 	/*  [     **** *****     ]  */
		0x0F, 0x9E, 0x00, 	/*  [    *****  ****     ]  */
		0x0F, 0x1F, 0x00, 	/*  [    ****   *****    ]  */
		0x1E, 0x0F, 0x80, 	/*  [   ****     *****   ]  */
		0x3C, 0x07, 0xC0, 	/*  [  ****       *****  ]  */
		0x7C, 0x03, 0xE0, 	/*  [ *****        ***** ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'y' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x7C, 0x01, 0xE0, 	/*  [ *****         **** ]  */
		0x3C, 0x01, 0xC0, 	/*  [  ****         ***  ]  */
		0x3C, 0x03, 0xC0, 	/*  [  ****        ****  ]  */
		0x1E, 0x03, 0x80, 	/*  [   ****       ***   ]  */
		0x1E, 0x07, 0x80, 	/*  [   ****      ****   ]  */
		0x1F, 0x07, 0x80, 	/*  [   *****     ****   ]  */
		0x0F, 0x0F, 0x00, 	/*  [    ****    ****    ]  */
		0x0F, 0x8F, 0x00, 	/*  [    *****   ****    ]  */
		0x07, 0x9E, 0x00, 	/*  [     ****  ****     ]  */
		0x07, 0x9E, 0x00, 	/*  [     ****  ****     ]  */
		0x03, 0xDC, 0x00, 	/*  [      **** ***      ]  */
		0x03, 0xFC, 0x00, 	/*  [      ********      ]  */
		0x03, 0xF8, 0x00, 	/*  [      *******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x01, 0xF8, 0x00, 	/*  [       ******       ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x03, 0xC0, 0x00, 	/*  [      ****          ]  */
		0x3F, 0x80, 0x00, 	/*  [  *******           ]  */
		0x3E, 0x00, 0x00, 	/*  [  *****             ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* 'z' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x3F, 0xFF, 0xC0, 	/*  [  ****************  ]  */
		0x3F, 0xFF, 0xC0, 	/*  [  ****************  ]  */
		0x00, 0x07, 0xC0, 	/*  [             *****  ]  */
		0x00, 0x0F, 0x80, 	/*  [            *****   ]  */
		0x00, 0x1F, 0x00, 	/*  [           *****    ]  */
		0x00, 0x3E, 0x00, 	/*  [          *****     ]  */
		0x00, 0x7C, 0x00, 	/*  [         *****      ]  */
		0x00, 0xF8, 0x00, 	/*  [        *****       ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x01, 0xE0, 0x00, 	/*  [       ****         ]  */
		0x03, 0xE0, 0x00, 	/*  [      *****         ]  */
		0x07, 0xC0, 0x00, 	/*  [     *****          ]  */
		0x0F, 0x80, 0x00, 	/*  [    *****           ]  */
		0x1F, 0x00, 0x00, 	/*  [   *****            ]  */
		0x3E, 0x00, 0x00, 	/*  [  *****             ]  */
		0x3F, 0xFF, 0xC0, 	/*  [  ****************  ]  */
		0x3F, 0xFF, 0xC0, 	/*  [  ****************  ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '{' charwidth: 20 */
		0x00, 0x1F, 0x80, 	/*  [           ******   ]  */
		0x00, 0x7F, 0x80, 	/*  [         ********   ]  */
		0x00, 0xF8, 0x00, 	/*  [        *****       ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF8, 0x00, 	/*  [        *****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x0F, 0xE0, 0x00, 	/*  [    *******         ]  */
		0x0F, 0xE0, 0x00, 	/*  [    *******         ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0xF8, 0x00, 	/*  [        *****       ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF8, 0x00, 	/*  [        *****       ]  */
		0x00, 0x7F, 0x80, 	/*  [         ********   ]  */
		0x00, 0x1F, 0x80, 	/*  [           ******   ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '|' charwidth: 20 */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0xE0, 0x00, 	/*  [        ***         ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '}' charwidth: 20 */
		0x0F, 0xC0, 0x00, 	/*  [    ******          ]  */
		0x0F, 0xF0, 0x00, 	/*  [    ********        ]  */
		0x00, 0xF8, 0x00, 	/*  [        *****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0xF8, 0x00, 	/*  [        *****       ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x3F, 0x80, 	/*  [          *******   ]  */
		0x00, 0x3F, 0x80, 	/*  [          *******   ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF0, 0x00, 	/*  [        ****        ]  */
		0x00, 0xF8, 0x00, 	/*  [        *****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0x78, 0x00, 	/*  [         ****       ]  */
		0x00, 0xF8, 0x00, 	/*  [        *****       ]  */
		0x0F, 0xF0, 0x00, 	/*  [    ********        ]  */
		0x0F, 0xC0, 0x00, 	/*  [    ******          ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
		/* '~' charwidth: 20 */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x1F, 0x00, 0x00, 	/*  [   *****            ]  */
		0x3F, 0xC0, 0xE0, 	/*  [  ********      *** ]  */
		0x39, 0xE0, 0xE0, 	/*  [  ***  ****     *** ]  */
		0x70, 0xF0, 0xE0, 	/*  [ ***    ****    *** ]  */
		0x70, 0x79, 0xC0, 	/*  [ ***     ****  ***  ]  */
		0x70, 0x3F, 0xC0, 	/*  [ ***      ********  ]  */
		0x00, 0x0F, 0x80, 	/*  [            *****   ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		0x00, 0x00, 0x00, 	/*  [                    ]  */
		
};
